@@ -158,8 +158,6 @@ struct _GnomeClient
   gboolean            save_phase_2_requested : 1;
   gboolean            save_successfull : 1;
   gboolean            save_yourself_emitted : 1;
-
-  gpointer            reserved; /* Reserved for private struct */
 };
 
 
@@ -180,18 +178,14 @@ struct _GnomeClientClass
   void (* connect)            (GnomeClient        *client,
 			       gint                restarted);
   void (* disconnect)         (GnomeClient        *client);
-
-  /* Padding for possible expansion */
-  gpointer padding1;
-  gpointer padding2;
 };
 
-#define GNOME_CLIENT_MODULE gnome_client_module_info_get()
-const GnomeModuleInfo *gnome_client_module_info_get (void) G_GNUC_CONST;
+extern GnomeModuleInfo gnome_client_module_info;
+#define GNOME_CLIENT_INIT GNOME_PARAM_MODULE,&gnome_client_module_info
+#define GNOME_CLIENT_PARAM_SM_CONNECT "B:libgnomeui/gnome-client/sm_connect"
 
-#define GNOME_CLIENT_PARAM_SM_CONNECT "sm-connect"
-
-GType        gnome_client_get_type (void) G_GNUC_CONST;
+/* For internal use by the gnome-libs: */
+guint        gnome_client_get_type (void) G_GNUC_CONST;
 
 /* Get the master session management client.  This master client gets
    a client id, that may be specified by the '--sm-client-id' command
@@ -390,15 +384,11 @@ void	     gnome_client_request_save (GnomeClient	       *client,
    get committed.  */
 void         gnome_client_flush (GnomeClient *client);
 
-#ifndef GNOME_DISABLE_DEPRECATED
-/* Note: Use the GNOME_CLIENT_PARAM_SM_CONNECT property
- * of GnomeProgram */
 /* Normally the master client is connected to the session manager
    automatically, when calling 'gnome_init'.  One can disable this
    automatic connect by calling this function. Using this function
    should definitely be an exception.  */
 void         gnome_client_disable_master_connection (void);
-#endif /* GNOME_DISABLE_DEPRECATED */
 
 /* Create a new session management client and try to connect to a
    session manager. This is useful if you are acting as a proxy for
@@ -434,12 +424,6 @@ const gchar*       gnome_client_get_id                 (GnomeClient *client);
    manager tries to maintain the same id from one session to another. */
 const gchar*       gnome_client_get_previous_id        (GnomeClient *client);
 
-/* Get the client ID of the desktop's current instance, i.e.  if you
- * consider the desktop as a whole as a session managed app, this
- * returns its session ID (GNOME extension to SM)
- */
-const gchar*       gnome_client_get_desktop_id   (GnomeClient *client);
-
 /* Use the following functions, if you want to interact with the user
    during a "save_yourself" handler without being restricted to using 
    the dialog based commands gnome_client_save_[any/error]_dialog.  
