@@ -28,8 +28,6 @@
  */
 
 #include <config.h>
-#include <libgnome/gnome-macros.h>
-
 #include <gtk/gtkmain.h>
 #include <gtk/gtkalignment.h>
 #include <gtk/gtkcolorsel.h>
@@ -38,12 +36,9 @@
 #include <gtk/gtkdrawingarea.h>
 #include <gtk/gtkframe.h>
 #include <gtk/gtksignal.h>
-
-/* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
-
-#include "gnome-marshal.h"
+#include <gtk/gtkcompat.h>
 #include "gnome-color-picker.h"
+#include <libgnome/gnome-i18n.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtkbutton.h>
 
@@ -93,6 +88,8 @@ enum {
 	LAST_SIGNAL
 };
 
+static void gnome_color_picker_class_init (GnomeColorPickerClass *class);
+static void gnome_color_picker_init       (GnomeColorPicker      *cp);
 static void gnome_color_picker_destroy    (GtkObject             *object);
 static void gnome_color_picker_finalize   (GObject               *object);
 static void gnome_color_picker_clicked    (GtkButton             *button);
@@ -125,10 +122,32 @@ static void gnome_color_picker_get_property (GObject            *object,
 
 static guint color_picker_signals[LAST_SIGNAL] = { 0 };
 
+static GtkButtonClass *parent_class;
+
 static GtkTargetEntry drop_types[] = { { "application/x-color", 0, 0 } };
 
-GNOME_CLASS_BOILERPLATE (GnomeColorPicker, gnome_color_picker,
-			 GtkButton, GTK_TYPE_BUTTON)
+GtkType
+gnome_color_picker_get_type (void)
+{
+	static GtkType cp_type = 0;
+
+	if (!cp_type) {
+		GtkTypeInfo cp_info = {
+			"GnomeColorPicker",
+			sizeof (GnomeColorPicker),
+			sizeof (GnomeColorPickerClass),
+			(GtkClassInitFunc) gnome_color_picker_class_init,
+			(GtkObjectInitFunc) gnome_color_picker_init,
+			NULL, /* reserved_1 */
+			NULL, /* reserved_2 */
+			(GtkClassInitFunc) NULL
+		};
+
+		cp_type = gtk_type_unique (gtk_button_get_type (), &cp_info);
+	}
+
+	return cp_type;
+}
 
 static void
 gnome_color_picker_class_init (GnomeColorPickerClass *class)
@@ -142,19 +161,19 @@ gnome_color_picker_class_init (GnomeColorPickerClass *class)
 	gobject_class = (GObjectClass *) class;
 	button_class = (GtkButtonClass *) class;
 	widget_class = (GtkWidgetClass *) class;
+	parent_class = gtk_type_class (gtk_button_get_type ());
 
 	color_picker_signals[COLOR_SET] =
-		g_signal_new ("color_set",
-			      G_TYPE_FROM_CLASS (gobject_class),
-			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (GnomeColorPickerClass, color_set),
-			      NULL, NULL,
-			      _gnome_marshal_VOID__UINT_UINT_UINT_UINT,
-			      G_TYPE_NONE, 4,
-			      G_TYPE_UINT,
-			      G_TYPE_UINT,
-			      G_TYPE_UINT,
-			      G_TYPE_UINT);
+		gtk_signal_new ("color_set",
+				GTK_RUN_FIRST,
+				GTK_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (GnomeColorPickerClass, color_set),
+				gnome_marshal_VOID__UINT_UINT_UINT_UINT,
+				GTK_TYPE_NONE, 4,
+				GTK_TYPE_UINT,
+				GTK_TYPE_UINT,
+				GTK_TYPE_UINT,
+				GTK_TYPE_UINT);
 
 	gobject_class->get_property = gnome_color_picker_get_property;
 	gobject_class->set_property = gnome_color_picker_set_property;
@@ -337,6 +356,8 @@ expose_event (GtkWidget *widget, GdkEventExpose *event, gpointer data)
 	GnomeColorPicker *cp;
 
 	cp = GNOME_COLOR_PICKER (data);
+	if (cp->_priv->gc == NULL)
+		cp->_priv->gc = gdk_gc_new (widget->window);
 
 	gdk_pixbuf_render_to_drawable (cp->_priv->pixbuf,
 				       widget->window,
@@ -357,20 +378,15 @@ gnome_color_picker_realize (GtkWidget *widget)
 {
 	GnomeColorPicker *cp = GNOME_COLOR_PICKER (widget);
 
-	GNOME_CALL_PARENT (GTK_WIDGET_CLASS, realize, (widget));
-
-	if (cp->_priv->gc == NULL)
-		cp->_priv->gc = gdk_gc_new (widget->window);
-
+	if (GTK_WIDGET_CLASS(parent_class)->realize)
+		GTK_WIDGET_CLASS (parent_class)->realize (widget);
 	render (cp);
 }
-
 static void
 gnome_color_picker_style_set (GtkWidget *widget, GtkStyle *previous_style)
 {
-	GNOME_CALL_PARENT (GTK_WIDGET_CLASS, style_set,
-				   (widget, previous_style));
-
+	if (GTK_WIDGET_CLASS(parent_class)->style_set)
+		GTK_WIDGET_CLASS (parent_class)->style_set (widget, previous_style);
 	if (GTK_WIDGET_REALIZED (widget))
 		render (GNOME_COLOR_PICKER (widget));
 }
@@ -400,7 +416,7 @@ drag_data_received (GtkWidget        *widget,
 	if (selection_data->length < 0)
 		return;
 
-	if ((selection_data->format != 16) ||
+	if ((selection_data->format != 16) || 
 	    (selection_data->length != 8)) {
 		g_warning (_("Received invalid color data\n"));
 		return;
@@ -411,12 +427,9 @@ drag_data_received (GtkWidget        *widget,
 
 	gnome_color_picker_set_i16(cpicker, dropped[0], dropped[1],
 				   dropped[2], dropped[3]);
-	g_signal_emit (cpicker, color_picker_signals[COLOR_SET], 0,
-		       dropped[0], dropped[1], dropped[2], dropped[3]);
-		
 }
 
-static void
+static void  
 drag_data_get  (GtkWidget          *widget,
 		GdkDragContext     *context,
 		GtkSelectionData   *selection_data,
@@ -440,7 +453,7 @@ drag_data_get  (GtkWidget          *widget,
 }
 
 static void
-gnome_color_picker_instance_init (GnomeColorPicker *cp)
+gnome_color_picker_init (GnomeColorPicker *cp)
 {
 	GtkWidget *alignment;
 	GtkWidget *frame;
@@ -458,13 +471,14 @@ gnome_color_picker_instance_init (GnomeColorPicker *cp)
 	gtk_container_add (GTK_CONTAINER (alignment), frame);
 	gtk_widget_show (frame);
 
-	gtk_widget_push_colormap (gdk_rgb_get_colormap ());
+	gtk_widget_push_colormap (gdk_rgb_get_cmap ());
 
 	cp->_priv->drawing_area = gtk_drawing_area_new ();
 
-	gtk_widget_set_size_request (cp->_priv->drawing_area, COLOR_PICKER_WIDTH, COLOR_PICKER_HEIGHT);
-	g_signal_connect (cp->_priv->drawing_area, "expose_event",
-			  G_CALLBACK (expose_event), cp);
+	gtk_drawing_area_size (GTK_DRAWING_AREA (cp->_priv->drawing_area), COLOR_PICKER_WIDTH, COLOR_PICKER_HEIGHT);
+	gtk_signal_connect (GTK_OBJECT (cp->_priv->drawing_area), "expose_event",
+			    (GtkSignalFunc) expose_event,
+			    cp);
 	gtk_container_add (GTK_CONTAINER (frame), cp->_priv->drawing_area);
 	gtk_widget_show (cp->_priv->drawing_area);
 
@@ -497,10 +511,12 @@ gnome_color_picker_instance_init (GnomeColorPicker *cp)
 			     GDK_BUTTON1_MASK|GDK_BUTTON3_MASK,
 			     drop_types, 1,
 			     GDK_ACTION_COPY);
-	g_signal_connect (cp, "drag_data_received",
-			  G_CALLBACK (drag_data_received), cp);
-	g_signal_connect (cp, "drag_data_get",
-			  G_CALLBACK (drag_data_get), cp);
+	gtk_signal_connect (GTK_OBJECT (cp),
+			    "drag_data_received",
+			    GTK_SIGNAL_FUNC (drag_data_received), cp);
+	gtk_signal_connect (GTK_OBJECT (cp),
+			    "drag_data_get",
+			    GTK_SIGNAL_FUNC (drag_data_get), cp);
 }
 
 static void
@@ -515,15 +531,22 @@ gnome_color_picker_destroy (GtkObject *object)
 
 	cp = GNOME_COLOR_PICKER (object);
 
-	if (cp->_priv->gc != NULL)
-		g_object_unref (G_OBJECT (cp->_priv->gc));
+	if(cp->_priv->pixbuf)
+		gdk_pixbuf_unref (cp->_priv->pixbuf);
+	cp->_priv->pixbuf = NULL;
+	if(cp->_priv->gc)
+		gdk_gc_destroy (cp->_priv->gc);
 	cp->_priv->gc = NULL;
 
-	if (cp->_priv->cs_dialog != NULL)
+	if (cp->_priv->cs_dialog)
 		gtk_widget_destroy (cp->_priv->cs_dialog);
 	cp->_priv->cs_dialog = NULL;
 
-	GNOME_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	g_free (cp->_priv->title);
+	cp->_priv->title = NULL;
+
+	if (GTK_OBJECT_CLASS (parent_class)->destroy)
+		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
 }
 
 static void
@@ -536,17 +559,11 @@ gnome_color_picker_finalize (GObject *object)
 
 	cp = GNOME_COLOR_PICKER (object);
 
-	if (cp->_priv->pixbuf != NULL)
-		g_object_unref (G_OBJECT (cp->_priv->pixbuf));
-	cp->_priv->pixbuf = NULL;
-
-	g_free (cp->_priv->title);
-	cp->_priv->title = NULL;
-
 	g_free (cp->_priv);
 	cp->_priv = NULL;
 
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
+	if (G_OBJECT_CLASS (parent_class)->finalize)
+		(* G_OBJECT_CLASS (parent_class)->finalize) (object);
 }
 
 
@@ -565,7 +582,7 @@ gnome_color_picker_finalize (GObject *object)
 GtkWidget *
 gnome_color_picker_new (void)
 {
-	return g_object_new (GNOME_TYPE_COLOR_PICKER, NULL);
+	return GTK_WIDGET (gtk_type_new (gnome_color_picker_get_type ()));
 }
 
 /* Callback used when the color selection dialog is destroyed */
@@ -586,33 +603,28 @@ static void
 cs_ok_clicked (GtkWidget *widget, gpointer data)
 {
 	GnomeColorPicker *cp;
-	GtkColorSelection *cs;
-	GdkColor color;
-	guint16 alpha;
+	gdouble color[4];
 	gushort r, g, b, a;
 
 	cp = GNOME_COLOR_PICKER (data);
 
-	cs = GTK_COLOR_SELECTION (GTK_COLOR_SELECTION_DIALOG (cp->_priv->cs_dialog)->colorsel);
-
-	gtk_color_selection_get_current_color (cs, &color);
-	alpha = gtk_color_selection_get_current_alpha (cs);
-
+	gtk_color_selection_get_color (GTK_COLOR_SELECTION (GTK_COLOR_SELECTION_DIALOG (cp->_priv->cs_dialog)->colorsel),
+				       color);
 	gtk_widget_destroy (cp->_priv->cs_dialog);
 
-	cp->_priv->r = color.red / 65535.0;
-	cp->_priv->g = color.green / 65535.0;
-	cp->_priv->b = color.blue / 65535.0;
-	cp->_priv->a = cp->_priv->use_alpha ? (alpha / 65535.0) : 1.0;
+	cp->_priv->r = color[0];
+	cp->_priv->g = color[1];
+	cp->_priv->b = color[2];
+	cp->_priv->a = cp->_priv->use_alpha ? color[3] : 1.0;
 
 	render (cp);
-	gtk_widget_queue_draw (cp->_priv->drawing_area);
+	gtk_widget_draw (cp->_priv->drawing_area, NULL);
 
 	/* Notify the world that the color was set */
 
 	gnome_color_picker_get_i16 (cp, &r, &g, &b, &a);
-	g_signal_emit (cp, color_picker_signals[COLOR_SET], 0,
-		       r, g, b, a);
+	gtk_signal_emit (GTK_OBJECT (cp), color_picker_signals[COLOR_SET],
+			 r, g, b, a);
 }
 
 static int
@@ -630,8 +642,7 @@ gnome_color_picker_clicked (GtkButton *button)
 {
 	GnomeColorPicker *cp;
 	GtkColorSelectionDialog *csd;
-	GdkColor color;
-	guint16 alpha;
+	gdouble color[4];
 
 	g_return_if_fail (button != NULL);
 	g_return_if_fail (GNOME_IS_COLOR_PICKER (button));
@@ -649,25 +660,27 @@ gnome_color_picker_clicked (GtkButton *button)
                 GtkWidget *parent;
 
                 parent = gtk_widget_get_toplevel(GTK_WIDGET(cp));
-
+                
 		cp->_priv->cs_dialog = gtk_color_selection_dialog_new (cp->_priv->title);
 
                 if (parent)
                         gtk_window_set_transient_for(GTK_WINDOW(cp->_priv->cs_dialog),
                                                      GTK_WINDOW(parent));
-
+                
 		csd = GTK_COLOR_SELECTION_DIALOG (cp->_priv->cs_dialog);
-		g_signal_connect (cp->_priv->cs_dialog, "destroy",
-				  G_CALLBACK (cs_destroy), cp);
+		gtk_signal_connect (GTK_OBJECT (cp->_priv->cs_dialog), "destroy",
+				    (GtkSignalFunc) cs_destroy,
+				    cp);
 
-		g_signal_connect (cp->_priv->cs_dialog, "key_press_event",
-				  G_CALLBACK (key_pressed), cp);
-		g_signal_connect (csd->ok_button, "clicked",
-				  G_CALLBACK (cs_ok_clicked), cp);
+		gtk_signal_connect (GTK_OBJECT (cp->_priv->cs_dialog), "key_press_event",
+				    (GtkSignalFunc) key_pressed, cp);
+		gtk_signal_connect (GTK_OBJECT (csd->ok_button), "clicked",
+				    (GtkSignalFunc) cs_ok_clicked,
+				    cp);
 
-		g_signal_connect_swapped (csd->cancel_button, "clicked",
-					  G_CALLBACK (gtk_widget_destroy),
-					  cp->_priv->cs_dialog);
+		gtk_signal_connect_object (GTK_OBJECT (csd->cancel_button), "clicked",
+					   (GtkSignalFunc) gtk_widget_destroy,
+					   GTK_OBJECT(cp->_priv->cs_dialog));
 
 		/* FIXME: do something about the help button */
 
@@ -680,16 +693,14 @@ gnome_color_picker_clicked (GtkButton *button)
 	gtk_color_selection_set_has_opacity_control (GTK_COLOR_SELECTION (csd->colorsel),
 						     cp->_priv->use_alpha);
 
-	color.red   = (int) (cp->_priv->r * 65535 + 0.5);
-	color.green = (int) (cp->_priv->g * 65535 + 0.5);
-	color.blue  = (int) (cp->_priv->b * 65535 + 0.5);
-	alpha       = cp->_priv->use_alpha ? (int) (cp->_priv->a * 65535 + 0.5) : 65535;
+	color[0] = cp->_priv->r;
+	color[1] = cp->_priv->g;
+	color[2] = cp->_priv->b;
+	color[3] = cp->_priv->use_alpha ? cp->_priv->a : 1.0;
 
-	gtk_color_selection_set_previous_color (GTK_COLOR_SELECTION (csd->colorsel), &color);
-	gtk_color_selection_set_previous_alpha (GTK_COLOR_SELECTION (csd->colorsel), alpha);
-
-	gtk_color_selection_set_current_color (GTK_COLOR_SELECTION (csd->colorsel), &color);
-	gtk_color_selection_set_current_alpha (GTK_COLOR_SELECTION (csd->colorsel), alpha);
+	/* Hack: we set the color twice so that GtkColorSelection will remember its history */
+	gtk_color_selection_set_color (GTK_COLOR_SELECTION (csd->colorsel), color);
+	gtk_color_selection_set_color (GTK_COLOR_SELECTION (csd->colorsel), color);
 
 	gtk_widget_show (cp->_priv->cs_dialog);
 }
@@ -723,7 +734,7 @@ gnome_color_picker_set_d (GnomeColorPicker *cp, gdouble r, gdouble g, gdouble b,
 	cp->_priv->a = a;
 
 	render (cp);
-	gtk_widget_queue_draw (cp->_priv->drawing_area);
+	gtk_widget_draw (cp->_priv->drawing_area, NULL);
 }
 
 
@@ -784,7 +795,7 @@ gnome_color_picker_set_i8 (GnomeColorPicker *cp, guint8 r, guint8 g, guint8 b, g
 	cp->_priv->a = a / 255.0;
 
 	render (cp);
-	gtk_widget_queue_draw (cp->_priv->drawing_area);
+	gtk_widget_draw (cp->_priv->drawing_area, NULL);
 }
 
 
@@ -845,7 +856,7 @@ gnome_color_picker_set_i16 (GnomeColorPicker *cp, gushort r, gushort g, gushort
 	cp->_priv->a = a / 65535.0;
 
 	render (cp);
-	gtk_widget_queue_draw (cp->_priv->drawing_area);
+	gtk_widget_draw (cp->_priv->drawing_area, NULL);
 }
 
 
@@ -900,7 +911,7 @@ gnome_color_picker_set_dither (GnomeColorPicker *cp, gboolean dither)
 	cp->_priv->dither = dither ? TRUE : FALSE;
 
 	render (cp);
-	gtk_widget_queue_draw (cp->_priv->drawing_area);
+	gtk_widget_draw (cp->_priv->drawing_area, NULL);
 }
 
 
@@ -943,7 +954,7 @@ gnome_color_picker_set_use_alpha (GnomeColorPicker *cp, gboolean use_alpha)
 	cp->_priv->use_alpha = use_alpha ? TRUE : FALSE;
 
 	render (cp);
-	gtk_widget_queue_draw (cp->_priv->drawing_area);
+	gtk_widget_draw (cp->_priv->drawing_area, NULL);
 }
 
 /**
