@@ -29,26 +29,22 @@
  * Author: Miguel de Icaza
  */
 #include <config.h>
-#include <libgnome/gnome-macros.h>
+#include "gnome-macros.h"
 
 #include <time.h>
 #include <string.h>
 #include <stdlib.h> /* atoi */
+#include <ctype.h> /* isdigit */
 #include <stdio.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
-
-/* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
-
 #include "gnome-dateedit.h"
 #include <libgnome/gnome-i18n.h>
 
-#include "gnometypebuiltins.h"
 struct _GnomeDateEditPrivate {
 	GtkWidget *date_entry;
 	GtkWidget *date_button;
-
+	
 	GtkWidget *time_entry;
 	GtkWidget *time_popup;
 
@@ -60,7 +56,7 @@ struct _GnomeDateEditPrivate {
 
 	int       lower_hour;
 	int       upper_hour;
-
+	
 	int       flags;
 };
 
@@ -82,8 +78,14 @@ enum {
 static gint date_edit_signals [LAST_SIGNAL] = { 0 };
 
 
+static void gnome_date_edit_init         (GnomeDateEdit      *gde);
+static void gnome_date_edit_class_init   (GnomeDateEditClass *class);
 static void gnome_date_edit_destroy      (GtkObject          *object);
 static void gnome_date_edit_finalize     (GObject            *object);
+static void gnome_date_edit_forall       (GtkContainer       *container,
+					  gboolean	      include_internals,
+					  GtkCallback	      callback,
+					  gpointer	      callbabck_data);
 static void gnome_date_edit_set_property    (GObject            *object,
 					  guint               param_id,
 					  const GValue       *value,
@@ -93,10 +95,8 @@ static void gnome_date_edit_get_property    (GObject            *object,
 					  GValue             *value,
 					  GParamSpec         *pspec);
 
-static void create_children (GnomeDateEdit *gde);
-
 /* to get around warnings */
-static const char *strftime_date_format = "%x";
+const char *strftime_date_format = "%x";
 
 /**
  * gnome_date_edit_get_type:
@@ -105,13 +105,14 @@ static const char *strftime_date_format = "%x";
  */
 /* The following macro defines the get_type */
 GNOME_CLASS_BOILERPLATE(GnomeDateEdit, gnome_date_edit,
-			GtkHBox, GTK_TYPE_HBOX)
+			GtkHBox, gtk_hbox)
 
 static void
 hide_popup (GnomeDateEdit *gde)
 {
 	gtk_widget_hide (gde->_priv->cal_popup);
 	gtk_grab_remove (gde->_priv->cal_popup);
+	gdk_pointer_ungrab (GDK_CURRENT_TIME);
 }
 
 static void
@@ -120,12 +121,11 @@ day_selected (GtkCalendar *calendar, GnomeDateEdit *gde)
 	char buffer [256];
 	guint year, month, day;
 	struct tm mtm = {0};
-	char *str_utf8;
 
 	gtk_calendar_get_date (calendar, &year, &month, &day);
 
 	mtm.tm_mday = day;
-	mtm.tm_mon = month;
+	mtm.tm_mon = month - 1;
 	if (year > 1900)
 		mtm.tm_year = year - 1900;
 	else
@@ -134,15 +134,11 @@ day_selected (GtkCalendar *calendar, GnomeDateEdit *gde)
 	if (strftime (buffer, sizeof (buffer),
 		      strftime_date_format, &mtm) == 0)
 		strcpy (buffer, "???");
-	buffer[sizeof(buffer)-1] = '\0';
 
 	/* FIXME: what about set time */
 
-	str_utf8 = g_locale_to_utf8 (buffer, -1, NULL, NULL, NULL);
-	gtk_entry_set_text (GTK_ENTRY (gde->_priv->date_entry),
-			    str_utf8 ? str_utf8 : "");
-	g_free (str_utf8);
-	g_signal_emit (gde, date_edit_signals [DATE_CHANGED], 0);
+	gtk_entry_set_text (GTK_ENTRY (gde->_priv->date_entry), buffer);
+	gtk_signal_emit (GTK_OBJECT (gde), date_edit_signals [DATE_CHANGED]);
 }
 
 static void
@@ -169,9 +165,9 @@ key_press_popup (GtkWidget *widget, GdkEventKey *event, gpointer data)
 
 	if (event->keyval != GDK_Escape)
 		return FALSE;
-	
+
 	gde = data;
-	g_signal_stop_emission_by_name (widget, "key_press_event");
+	gtk_signal_emit_stop_by_name (GTK_OBJECT (widget), "key_press_event");
 	hide_popup (gde);
 
 	return TRUE;
@@ -218,11 +214,7 @@ position_popup (GnomeDateEdit *gde)
 	gtk_widget_size_request (gde->_priv->cal_popup, &req);
 
 	gdk_window_get_origin (gde->_priv->date_button->window, &x, &y);
-
-	x += gde->_priv->date_button->allocation.x;
-	y += gde->_priv->date_button->allocation.y;
-	bwidth = gde->_priv->date_button->allocation.width;
-	bheight = gde->_priv->date_button->allocation.height;
+	gdk_window_get_size (gde->_priv->date_button->window, &bwidth, &bheight);
 
 	x += bwidth - req.width;
 	y += bheight;
@@ -233,26 +225,7 @@ position_popup (GnomeDateEdit *gde)
 	if (y < 0)
 		y = 0;
 
-	gtk_window_move (GTK_WINDOW (gde->_priv->cal_popup), x, y);
-}
-
-static gboolean
-popup_grab_on_window (GdkWindow *window,
-		      guint32    activate_time)
-{
-	if ((gdk_pointer_grab (window, TRUE,
-			       GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
-			       GDK_POINTER_MOTION_MASK,
-			       NULL, NULL, activate_time) == 0)) {
-		if (gdk_keyboard_grab (window, TRUE,
-				       activate_time) == 0)
-			return TRUE;
-		else {
-			gdk_pointer_ungrab (activate_time);
-			return FALSE;
-		}
-	}
-	return FALSE;
+	gtk_widget_set_uposition (gde->_priv->cal_popup, x, y);
 }
 
 static void
@@ -260,26 +233,14 @@ select_clicked (GtkWidget *widget, GnomeDateEdit *gde)
 {
 	const char *str;
 	GDate *date;
-	int month;
-	
-	/* Temporarily grab pointer and keyboard on a window we know exists; we
-	   + * do this so that the grab (with owner events == TRUE) affects
-	   + * events generated when the window is mapped, such as enter
-	   + * notify events on subwidgets. If the grab fails, bail out.
-	   + */
-	if (!popup_grab_on_window (widget->window,
-				   gtk_get_current_event_time ()))
-		return;
-	
+
 	str = gtk_entry_get_text (GTK_ENTRY (gde->_priv->date_entry));
 
 	date = g_date_new ();
 	g_date_set_parse (date, str);
-        /* GtkCalendar expects month to be in 0-11 range (inclusive) */
-	month = g_date_get_month (date) - 1;
 
 	gtk_calendar_select_month (GTK_CALENDAR (gde->_priv->calendar),
-				   CLAMP (month, 0, 11),
+				   g_date_get_month (date),
 				   g_date_get_year (date));
         gtk_calendar_select_day (GTK_CALENDAR (gde->_priv->calendar),
 				 g_date_get_day (date));
@@ -297,7 +258,7 @@ select_clicked (GtkWidget *widget, GnomeDateEdit *gde)
 
 	mtm.tm_mon = CLAMP (mtm.tm_mon, 1, 12);
 	mtm.tm_mday = CLAMP (mtm.tm_mday, 1, 31);
-
+        
         mtm.tm_mon--;
 
 	/* Hope the user does not actually mean years early in the A.D. days...
@@ -311,17 +272,16 @@ select_clicked (GtkWidget *widget, GnomeDateEdit *gde)
 #endif
 
         position_popup (gde);
-
-	gtk_grab_add (gde->_priv->cal_popup);
-	
+       
 	gtk_widget_show (gde->_priv->cal_popup);
-	gtk_widget_grab_focus (gde->_priv->calendar);
+	gtk_widget_grab_focus (gde->_priv->cal_popup);
+	gtk_grab_add (gde->_priv->cal_popup);
 
-	/* Now transfer our grabs to the popup window; this
-	 * should always succeed.
-	 */
-	popup_grab_on_window (gde->_priv->cal_popup->window,
-			      gtk_get_current_event_time ());
+	gdk_pointer_grab (gde->_priv->cal_popup->window, TRUE,
+			  (GDK_BUTTON_PRESS_MASK
+			   | GDK_BUTTON_RELEASE_MASK
+			   | GDK_POINTER_MOTION_MASK),
+			  NULL, NULL, GDK_CURRENT_TIME);
 }
 
 typedef struct {
@@ -333,7 +293,7 @@ static void
 set_time (GtkWidget *widget, hour_info_t *hit)
 {
 	gtk_entry_set_text (GTK_ENTRY (hit->gde->_priv->time_entry), hit->hour);
-	g_signal_emit (hit->gde, date_edit_signals [TIME_CHANGED], 0);
+	gtk_signal_emit (GTK_OBJECT (hit->gde), date_edit_signals [TIME_CHANGED]);
 }
 
 static void
@@ -358,15 +318,15 @@ fill_time_popup (GtkWidget *widget, GnomeDateEdit *gde)
 		return;
 
 	menu = gtk_menu_new ();
+	gtk_option_menu_set_menu (GTK_OPTION_MENU (gde->_priv->time_popup), menu);
 
 	time (&current_time);
 	mtm = localtime (&current_time);
-
+	
 	for (i = gde->_priv->lower_hour; i <= gde->_priv->upper_hour; i++){
 		GtkWidget *item, *submenu;
 		hour_info_t *hit;
 		char buffer [40];
-		char *str_utf8;
 
 		mtm->tm_hour = i;
 		mtm->tm_min  = 0;
@@ -380,20 +340,19 @@ fill_time_popup (GtkWidget *widget, GnomeDateEdit *gde)
 				      "%I:00 %p ", mtm) == 0)
 				strcpy (buffer, "???");
 		}
-		buffer[sizeof(buffer)-1] = '\0';
-		str_utf8 = g_locale_to_utf8 (buffer, -1, NULL, NULL, NULL);
-		item = gtk_menu_item_new_with_label (str_utf8 ? str_utf8 : "");
-		g_free (str_utf8);
+		item = gtk_menu_item_new_with_label (buffer);
 		gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 #if 0
 		hit = g_new (hour_info_t, 1);
 		hit->hour = g_strdup (buffer);
 		hit->gde  = gde;
-		g_signal_connect_data (item, "activate",
-				       G_CALLBACK (set_time),
-				       hit,
-				       (GCallbackNotify) free_resources,
-				       0);
+		gtk_signal_connect_full (GTK_OBJECT (item), "activate",
+					 GTK_SIGNAL_FUNC (set_time),
+					 NULL,
+					 hit,
+					 free_resources,
+					 FALSE /*object*/,
+					 FALSE /*after*/);
 #endif
 		gtk_widget_show (item);
 
@@ -413,26 +372,24 @@ fill_time_popup (GtkWidget *widget, GnomeDateEdit *gde)
 					      "%I:%M %p", mtm) == 0)
 					strcpy (buffer, "???");
 			}
-			buffer[sizeof(buffer)-1] = '\0';
-			str_utf8 = g_locale_to_utf8 (buffer, -1, NULL, NULL, NULL);
-			mins = gtk_menu_item_new_with_label (str_utf8 ? str_utf8 : "");
-			g_free (str_utf8);
 
+			mins = gtk_menu_item_new_with_label (buffer);
 			gtk_menu_shell_append (GTK_MENU_SHELL (submenu), mins);
 
 			hit = g_new (hour_info_t, 1);
 			hit->hour = g_strdup (buffer);
 			hit->gde  = gde;
-			g_signal_connect_data (mins, "activate",
-					       G_CALLBACK (set_time),
-					       hit,
-					       (GClosureNotify) free_resources,
-					       0);
+			gtk_signal_connect_full (GTK_OBJECT (mins), "activate",
+						 GTK_SIGNAL_FUNC (set_time),
+						 NULL,
+						 hit,
+						 free_resources,
+						 FALSE /*object*/,
+						 FALSE /*after*/);
+
 			gtk_widget_show (mins);
 		}
 	}
-	/* work around a GtkOptionMenu bug #66969 */
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (gde->_priv->time_popup), menu);
 }
 
 static void
@@ -440,100 +397,99 @@ gnome_date_edit_class_init (GnomeDateEditClass *class)
 {
 	GtkObjectClass *object_class = (GtkObjectClass *) class;
 	GObjectClass *gobject_class = (GObjectClass *) class;
+	GtkContainerClass *container_class = (GtkContainerClass *) class;
 
 	object_class = (GtkObjectClass*) class;
 
+	g_object_class_install_property (gobject_class,
+				      PROP_TIME,
+				      g_param_spec_ulong ("time",
+							  _("Time"),
+							  _("The time currently"
+							    "selected"),
+							  0, G_MAXULONG,
+							  0,
+						          (G_PARAM_READABLE |
+							   G_PARAM_WRITABLE)));
+	/* FIXME: Not sure G_TYPE_FLAGS is right here, perhaps we
+	 * need a new type, Also think of a better name then "dateedit_flags" */
+	g_object_class_install_property (gobject_class,
+				      PROP_DATEEDIT_FLAGS,
+				      g_param_spec_flags ("dateedit_flags",
+							  _("DateEdit Flags"),
+							  _("Flags for how "
+							    "DateEdit looks"),
+							  G_TYPE_FLAGS,
+							  GNOME_DATE_EDIT_SHOW_TIME,
+						          (G_PARAM_READABLE |
+							   G_PARAM_WRITABLE)));
+	g_object_class_install_property (gobject_class,
+				      PROP_LOWER_HOUR,
+				      g_param_spec_int ("lower_hour",
+							_("Lower Hour"),
+							_("Lower hour in "
+							  "the time popup "
+							  "selector"),
+							0, 24,
+							7,
+							(G_PARAM_READABLE |
+							 G_PARAM_WRITABLE)));
+	g_object_class_install_property (gobject_class,
+				      PROP_UPPER_HOUR,
+				      g_param_spec_int ("upper_hour",
+							_("Upper Hour"),
+							_("Upper hour in "
+							  "the time popup "
+							  "selector"),
+							0, 24,
+							19,
+							(G_PARAM_READABLE |
+							 G_PARAM_WRITABLE)));
+	g_object_class_install_property (gobject_class,
+				      PROP_INITIAL_TIME,
+				      g_param_spec_ulong ("initial_time",
+							  _("Initial Time"),
+							  _("The initial time"),
+							  0, G_MAXULONG,
+							  0,
+						          (G_PARAM_READABLE |
+							   G_PARAM_WRITABLE)));
+	
+	date_edit_signals [TIME_CHANGED] =
+		gtk_signal_new ("time_changed",
+				GTK_RUN_FIRST, GTK_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (GnomeDateEditClass,
+						   time_changed),
+				gtk_signal_default_marshaller,
+				GTK_TYPE_NONE, 0);
+	
+	date_edit_signals [DATE_CHANGED] =
+		gtk_signal_new ("date_changed",
+				GTK_RUN_FIRST, GTK_CLASS_TYPE (object_class),
+				GTK_SIGNAL_OFFSET (GnomeDateEditClass,
+						   date_changed),
+				gtk_signal_default_marshaller,
+				GTK_TYPE_NONE, 0);
+	
+	container_class->forall = gnome_date_edit_forall;
+
 	object_class->destroy = gnome_date_edit_destroy;
 
 	gobject_class->finalize = gnome_date_edit_finalize;
 	gobject_class->get_property = gnome_date_edit_get_property;
 	gobject_class->set_property = gnome_date_edit_set_property;
 
-	g_object_class_install_property (gobject_class,
-					 PROP_TIME,
-					 g_param_spec_ulong ("time",
-							     _("Time"),
-							     _("The time currently "
-							       "selected"),
-							     0, G_MAXULONG,
-							     0,
-							     (G_PARAM_READABLE |
-							      G_PARAM_WRITABLE)));
-
-	/* FIXME: Not sure G_TYPE_FLAGS is right here, perhaps we
-	 * need a new type, Also think of a better name then "dateedit_flags" */
-	g_object_class_install_property (gobject_class,
-					 PROP_DATEEDIT_FLAGS,
-					 g_param_spec_flags ("dateedit_flags",
-							     _("DateEdit Flags"),
-							     _("Flags for how "
-							       "DateEdit looks"),
-							     GNOME_TYPE_DATE_EDIT_FLAGS,
-							     GNOME_DATE_EDIT_SHOW_TIME,
-							     (G_PARAM_READABLE |
-							      G_PARAM_WRITABLE)));
-	g_object_class_install_property (gobject_class,
-					 PROP_LOWER_HOUR,
-					 g_param_spec_int ("lower_hour",
-							   _("Lower Hour"),
-							   _("Lower hour in "
-							     "the time popup "
-							     "selector"),
-							   0, 24,
-							   7,
-							   (G_PARAM_READABLE |
-							    G_PARAM_WRITABLE)));
-	g_object_class_install_property (gobject_class,
-					 PROP_UPPER_HOUR,
-					 g_param_spec_int ("upper_hour",
-							   _("Upper Hour"),
-							   _("Upper hour in "
-							     "the time popup "
-							     "selector"),
-							   0, 24,
-							   19,
-							   (G_PARAM_READABLE |
-							    G_PARAM_WRITABLE)));
-	g_object_class_install_property (gobject_class,
-					 PROP_INITIAL_TIME,
-					 g_param_spec_ulong ("initial_time",
-							     _("Initial Time"),
-							     _("The initial time"),
-							     0, G_MAXULONG,
-							     0,
-							     (G_PARAM_READABLE |
-							      G_PARAM_WRITABLE)));
-
-	date_edit_signals [TIME_CHANGED] =
-		g_signal_new ("time_changed",
-			      G_TYPE_FROM_CLASS (gobject_class),
-			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (GnomeDateEditClass, time_changed),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE, 0);
-
-	date_edit_signals [DATE_CHANGED] =
-		g_signal_new ("date_changed",
-			      G_TYPE_FROM_CLASS (gobject_class),
-			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (GnomeDateEditClass, date_changed),
-			      NULL, NULL,
-			      g_cclosure_marshal_VOID__VOID,
-			      G_TYPE_NONE, 0);
-
 	class->date_changed = NULL;
 	class->time_changed = NULL;
 }
 
 static void
-gnome_date_edit_instance_init (GnomeDateEdit *gde)
+gnome_date_edit_init (GnomeDateEdit *gde)
 {
 	gde->_priv = g_new0(GnomeDateEditPrivate, 1);
 	gde->_priv->lower_hour = 7;
 	gde->_priv->upper_hour = 19;
 	gde->_priv->flags = GNOME_DATE_EDIT_SHOW_TIME;
-	create_children (gde);
 }
 
 static void
@@ -552,7 +508,7 @@ gnome_date_edit_destroy (GtkObject *object)
 		gtk_widget_destroy (gde->_priv->cal_popup);
 	gde->_priv->cal_popup = NULL;
 
-	GNOME_CALL_PARENT (GTK_OBJECT_CLASS, destroy, (object));
+	GNOME_CALL_PARENT_HANDLER (GTK_OBJECT_CLASS, destroy, (object));
 }
 
 static void
@@ -568,7 +524,26 @@ gnome_date_edit_finalize (GObject *object)
 	g_free(gde->_priv);
 	gde->_priv = NULL;
 
-	GNOME_CALL_PARENT (G_OBJECT_CLASS, finalize, (object));
+	GNOME_CALL_PARENT_HANDLER (G_OBJECT_CLASS, finalize, (object));
+}
+
+static void
+gnome_date_edit_forall (GtkContainer *container, gboolean include_internals,
+			GtkCallback callback, gpointer callback_data)
+{
+	g_return_if_fail (container != NULL);
+	g_return_if_fail (GNOME_IS_DATE_EDIT (container));
+	g_return_if_fail (callback != NULL);
+
+	/* Let GtkBox handle things only if the internal widgets need to be
+	 * poked.
+	 */
+	if (include_internals)
+		GNOME_CALL_PARENT_HANDLER (GTK_CONTAINER_CLASS, forall,
+					   (container,
+					    include_internals,
+					    callback,
+					    callback_data));
 }
 
 static void
@@ -647,8 +622,7 @@ void
 gnome_date_edit_set_time (GnomeDateEdit *gde, time_t the_time)
 {
 	struct tm *mytm;
-	char buffer [256];
-	char *str_utf8;
+	char buffer [40];
 
 	g_return_if_fail(gde != NULL);
 
@@ -661,11 +635,7 @@ gnome_date_edit_set_time (GnomeDateEdit *gde, time_t the_time)
 	/* Set the date */
 	if (strftime (buffer, sizeof (buffer), strftime_date_format, mytm) == 0)
 		strcpy (buffer, "???");
-	buffer[sizeof(buffer)-1] = '\0';
-
-	str_utf8 = g_locale_to_utf8 (buffer, -1, NULL, NULL, NULL);
-	gtk_entry_set_text (GTK_ENTRY (gde->_priv->date_entry), str_utf8 ? str_utf8 : "");
-	g_free (str_utf8);
+	gtk_entry_set_text (GTK_ENTRY (gde->_priv->date_entry), buffer);
 
 	/* Set the time */
 	if (gde->_priv->flags & GNOME_DATE_EDIT_24_HR) {
@@ -675,11 +645,7 @@ gnome_date_edit_set_time (GnomeDateEdit *gde, time_t the_time)
 		if (strftime (buffer, sizeof (buffer), "%I:%M %p", mytm) == 0)
 			strcpy (buffer, "???");
 	}
-	buffer[sizeof(buffer)-1] = '\0';
-
-	str_utf8 = g_locale_to_utf8 (buffer, -1, NULL, NULL, NULL);
-	gtk_entry_set_text (GTK_ENTRY (gde->_priv->time_entry), str_utf8 ? str_utf8 : "");
-	g_free (str_utf8);
+	gtk_entry_set_text (GTK_ENTRY (gde->_priv->time_entry), buffer);
 }
 
 /**
@@ -712,13 +678,13 @@ create_children (GnomeDateEdit *gde)
 	GtkWidget *arrow;
 
 	gde->_priv->date_entry  = gtk_entry_new ();
-	gtk_widget_set_size_request (gde->_priv->date_entry, 90, -1);
+	gtk_widget_set_usize (gde->_priv->date_entry, 90, 0);
 	gtk_box_pack_start (GTK_BOX (gde), gde->_priv->date_entry, TRUE, TRUE, 0);
 	gtk_widget_show (gde->_priv->date_entry);
-
+	
 	gde->_priv->date_button = gtk_button_new ();
-	g_signal_connect (gde->_priv->date_button, "clicked",
-			  G_CALLBACK (select_clicked), gde);
+	gtk_signal_connect (GTK_OBJECT (gde->_priv->date_button), "clicked",
+			    GTK_SIGNAL_FUNC (select_clicked), gde);
 	gtk_box_pack_start (GTK_BOX (gde), gde->_priv->date_button, FALSE, FALSE, 0);
 
 	hbox = gtk_hbox_new (FALSE, 3);
@@ -734,14 +700,13 @@ create_children (GnomeDateEdit *gde)
 		gtk_widget_show (gde->_priv->cal_label);
 
 	arrow = gtk_arrow_new (GTK_ARROW_DOWN, GTK_SHADOW_OUT);
-	gtk_box_pack_start (GTK_BOX (hbox), arrow, TRUE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (hbox), arrow, FALSE, FALSE, 0);
 	gtk_widget_show (arrow);
 
 	gtk_widget_show (gde->_priv->date_button);
 
-	gde->_priv->time_entry = gtk_entry_new ();
-	gtk_entry_set_max_length (GTK_ENTRY (gde->_priv->time_entry), 12);
-	gtk_widget_set_size_request (gde->_priv->time_entry, 88, -1);
+	gde->_priv->time_entry = gtk_entry_new_with_max_length (12);
+	gtk_widget_set_usize (gde->_priv->time_entry, 88, 0);
 	gtk_box_pack_start (GTK_BOX (gde), gde->_priv->time_entry, TRUE, TRUE, 0);
 
 	gde->_priv->time_popup = gtk_option_menu_new ();
@@ -751,8 +716,8 @@ create_children (GnomeDateEdit *gde)
 	 * realized, so that it uses the values that the user might supply in a
 	 * future call to gnome_date_edit_set_popup_range
 	 */
-	g_signal_connect (gde, "realize",
-			  G_CALLBACK (fill_time_popup), gde);
+	gtk_signal_connect (GTK_OBJECT (gde), "realize",
+			    GTK_SIGNAL_FUNC (fill_time_popup), gde);
 
 	if (gde->_priv->flags & GNOME_DATE_EDIT_SHOW_TIME) {
 		gtk_widget_show (gde->_priv->time_entry);
@@ -762,16 +727,19 @@ create_children (GnomeDateEdit *gde)
 	gde->_priv->cal_popup = gtk_window_new (GTK_WINDOW_POPUP);
 	gtk_widget_set_events (gde->_priv->cal_popup,
 			       gtk_widget_get_events (gde->_priv->cal_popup) | GDK_KEY_PRESS_MASK);
-	g_signal_connect (gde->_priv->cal_popup, "delete_event",
-			  G_CALLBACK (delete_popup), gde);
-	g_signal_connect (gde->_priv->cal_popup, "key_press_event",
-			  G_CALLBACK (key_press_popup), gde);
-	g_signal_connect (gde->_priv->cal_popup, "button_press_event",
-			  G_CALLBACK (button_press_popup), gde);
-	gtk_window_set_resizable (GTK_WINDOW (gde->_priv->cal_popup), FALSE);
+	gtk_signal_connect (GTK_OBJECT (gde->_priv->cal_popup), "delete_event",
+			    (GtkSignalFunc) delete_popup,
+			    gde);
+	gtk_signal_connect (GTK_OBJECT (gde->_priv->cal_popup), "key_press_event",
+			    (GtkSignalFunc) key_press_popup,
+			    gde);
+	gtk_signal_connect (GTK_OBJECT (gde->_priv->cal_popup), "button_press_event",
+			    (GtkSignalFunc) button_press_popup,
+			    gde);
+	gtk_window_set_policy (GTK_WINDOW (gde->_priv->cal_popup), FALSE, FALSE, TRUE);
 
 	frame = gtk_frame_new (NULL);
-	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_OUT);
+	gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
 	gtk_container_add (GTK_CONTAINER (gde->_priv->cal_popup), frame);
 	gtk_widget_show (frame);
 
@@ -781,10 +749,10 @@ create_children (GnomeDateEdit *gde)
 				       | GTK_CALENDAR_SHOW_HEADING
 				       | ((gde->_priv->flags & GNOME_DATE_EDIT_WEEK_STARTS_ON_MONDAY)
 					  ? GTK_CALENDAR_WEEK_START_MONDAY : 0)));
-	g_signal_connect (gde->_priv->calendar, "day_selected",
-			  G_CALLBACK (day_selected), gde);
-	g_signal_connect (gde->_priv->calendar, "day_selected_double_click",
-			  G_CALLBACK (day_selected_double_click), gde);
+	gtk_signal_connect (GTK_OBJECT (gde->_priv->calendar), "day_selected",
+			    GTK_SIGNAL_FUNC (day_selected), gde);
+	gtk_signal_connect (GTK_OBJECT (gde->_priv->calendar), "day_selected_double_click",
+			    GTK_SIGNAL_FUNC (day_selected_double_click), gde);
 	gtk_container_add (GTK_CONTAINER (frame), gde->_priv->calendar);
         gtk_widget_show (gde->_priv->calendar);
 }
@@ -798,7 +766,7 @@ create_children (GnomeDateEdit *gde)
  * Description: Creates a new #GnomeDateEdit widget which can be used
  * to provide an easy to use way for entering dates and times.
  * If @the_time is 0 then current time is used.
- *
+ * 
  * Returns: a new #GnomeDateEdit widget.
  */
 GtkWidget *
@@ -813,10 +781,10 @@ gnome_date_edit_new (time_t the_time, gboolean show_time, gboolean use_24_format
  * gnome_date_edit_new_flags:
  * @the_time: The initial time for the date editor.
  * @flags: A bitmask of GnomeDateEditFlags values.
- *
+ * 
  * Description:  Creates a new #GnomeDateEdit widget with the
  * specified flags. If @the_time is 0 then current time is used.
- *
+ * 
  * Returns: the newly-created date editor widget.
  **/
 GtkWidget *
@@ -824,7 +792,7 @@ gnome_date_edit_new_flags (time_t the_time, GnomeDateEditFlags flags)
 {
 	GnomeDateEdit *gde;
 
-	gde = g_object_new (GNOME_TYPE_DATE_EDIT, NULL);
+	gde = gtk_type_new (gnome_date_edit_get_type ());
 
 	gnome_date_edit_construct(gde, the_time, flags);
 
@@ -836,13 +804,14 @@ gnome_date_edit_new_flags (time_t the_time, GnomeDateEditFlags flags)
  * @gde: The #GnomeDateEdit object to construct
  * @the_time: The initial time for the date editor.
  * @flags: A bitmask of GnomeDateEditFlags values.
- *
+ * 
  * Description:  For language bindings and subclassing only
  **/
 void
 gnome_date_edit_construct (GnomeDateEdit *gde, time_t the_time, GnomeDateEditFlags flags)
 {
-	gnome_date_edit_set_flags (gde, flags);
+	gde->_priv->flags = flags;
+	create_children (gde);
 	gnome_date_edit_set_time (gde, the_time);
 }
 
@@ -862,7 +831,7 @@ gnome_date_edit_get_time (GnomeDateEdit *gde)
 	/* Assert, because we're just hosed if it's NULL */
 	g_assert(gde != NULL);
 	g_assert(GNOME_IS_DATE_EDIT(gde));
-
+	
 	str = gtk_entry_get_text (GTK_ENTRY (gde->_priv->date_entry));
 
 	date = g_date_new ();
@@ -903,10 +872,10 @@ gnome_date_edit_get_time (GnomeDateEdit *gde)
 			tm.tm_hour = atoi (temp);
 			temp = strtok_r (NULL, ": ", &tokp);
 			if (temp) {
-				if (g_ascii_isdigit (*temp)) {
+				if (isdigit (*temp)) {
 					tm.tm_min = atoi (temp);
 					flags = strtok_r (NULL, ": ", &tokp);
-					if (flags && g_ascii_isdigit (*flags)) {
+					if (flags && isdigit (*flags)) {
 						tm.tm_sec = atoi (flags);
 						flags = strtok_r (NULL, ": ", &tokp);
 					}
@@ -915,9 +884,8 @@ gnome_date_edit_get_time (GnomeDateEdit *gde)
 			}
 		}
 
-		if (flags != NULL && tm.tm_hour < 12) {
+		if (flags != NULL) {
 			char buf[256] = "";
-			char *str_utf8;
 			struct tm pmtm = {0};
 
 			/* Get locale specific "PM", note that it
@@ -925,16 +893,10 @@ gnome_date_edit_get_time (GnomeDateEdit *gde)
 			pmtm.tm_hour = 17; /* around tea time is always PM */
 			if (strftime (buf, sizeof (buf), "%p", &pmtm) == 0)
 				strcpy (buf, "");
-			buf[sizeof(buf)-1] = '\0';
 
-			str_utf8 = g_locale_to_utf8 (buf, -1, NULL, NULL, NULL);
-
-			/* eek, this may be evil, we are sort of fuzzy here */
-			if ((str_utf8 != NULL && strcmp (flags, str_utf8) == 0) ||
-			    g_ascii_strcasecmp (flags, buf) == 0)
-				tm.tm_hour += 12;
-
-			g_free (str_utf8);
+			if (g_strcasecmp (flags, buf) == 0 &&
+			    tm.tm_hour < 12)
+					tm.tm_hour += 12;
 		}
 
 		g_free (string);
@@ -946,7 +908,7 @@ gnome_date_edit_get_time (GnomeDateEdit *gde)
 	return mktime (&tm);
 }
 
-#ifndef GNOME_DISABLE_DEPRECATED_SOURCE
+#ifndef GNOME_EXCLUDE_DEPRECATED_SOURCE
 
 /**
  * gnome_date_edit_get_date:
@@ -961,27 +923,27 @@ gnome_date_edit_get_date (GnomeDateEdit *gde)
 	return gnome_date_edit_get_time(gde);
 }
 
-#endif /* not GNOME_DISABLE_DEPRECATED_SOURCE */
+#endif /* not GNOME_EXCLUDE_DEPRECATED_SOURCE */
 
 
 /**
  * gnome_date_edit_set_flags:
  * @gde: The date editor widget whose flags should be changed.
  * @flags: The new bitmask of GnomeDateEditFlags values.
- *
+ * 
  * Changes the display flags on an existing date editor widget.
  **/
 void
 gnome_date_edit_set_flags (GnomeDateEdit *gde, GnomeDateEditFlags flags)
 {
         GnomeDateEditFlags old_flags;
-
+        
 	g_return_if_fail (gde != NULL);
 	g_return_if_fail (GNOME_IS_DATE_EDIT (gde));
 
         old_flags = gde->_priv->flags;
         gde->_priv->flags = flags;
-
+        
 	if ((flags & GNOME_DATE_EDIT_SHOW_TIME) != (old_flags & GNOME_DATE_EDIT_SHOW_TIME)) {
 		if (flags & GNOME_DATE_EDIT_SHOW_TIME) {
 			gtk_widget_show (gde->_priv->cal_label);
@@ -1013,9 +975,9 @@ gnome_date_edit_set_flags (GnomeDateEdit *gde, GnomeDateEditFlags flags)
 /**
  * gnome_date_edit_get_flags:
  * @gde: The date editor whose flags should be queried.
- *
+ * 
  * Queries the display flags on a date editor widget.
- *
+ * 
  * Return value: The current display flags for the specified date editor widget.
  **/
 int
@@ -1030,10 +992,10 @@ gnome_date_edit_get_flags (GnomeDateEdit *gde)
 /**
  * gnome_date_edit_get_initial_time:
  * @gde: The date editor whose initial time should be queried
- *
+ * 
  * Description:  Queries the initial time that was set using the
  * #gnome_date_edit_set_time or during creation
- *
+ * 
  * Returns:  The initial time in seconds (standard time_t format)
  **/
 time_t
