@@ -26,7 +26,9 @@
 
 /* Blame Elliot for most of this stuff*/
 
-#include <config.h>
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
 
 #include <errno.h>
 #include <stdarg.h>
@@ -40,72 +42,84 @@
 #include <locale.h>
 #endif
 
-/* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
-
-#include <libgnome/libgnome.h>
-#include <bonobo/bonobo-ui-main.h>
-#include <gconf/gconf-client.h>
+#include <libgnome.h>
+#include <libgnomeui/gnome-canvas-init.h>
 
 #include "gnome-client.h"
-#include "gnome-gconf-ui.h"
 #include "gnome-ui-init.h"
+#include "gnome-winhints.h"
 #include "gnome-stock-icons.h"
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include "libgnomeuiP.h"
 
-#include <gtk/gtkversion.h>
 #include <gtk/gtkmain.h>
-#include <gtk/gtkaccelmap.h>
 
-/* for sound events */
-#include <gtk/gtkmenuitem.h>
-#include <gtk/gtkbutton.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtktogglebutton.h>
-#include <gtk/gtkcheckmenuitem.h>
+/*****************************************************************************
+ * libbonoboui
+ *****************************************************************************/
+
+static void
+libbonoboui_pre_args_parse (GnomeProgram *program, GnomeModuleInfo *mod_info)
+{
+        /* Initialize libbonoboui here.
+         *
+         * Attention: libbonobo has already been initialized from libgnome !
+         */
+}
+
+static void
+libbonoboui_post_args_parse (GnomeProgram *program, GnomeModuleInfo *mod_info)
+{
+        /* Initialize libbonoboui here.
+         *
+         * Attention: libbonobo has already been initialized from libgnome !
+         */
+}
+
+static GnomeModuleRequirement libbonoboui_requirements[] = {
+        /* libgnome already depends on libbonobo, so we need to depend on
+         * libgnome here as well to make sure the init functions are called
+         * in the correct order. */
+        { VERSION, &libgnome_module_info },
+        { NULL, NULL }
+};
+
+GnomeModuleInfo libbonoboui_module_info = {
+        "libbonoboui", VERSION, N_("Bonobo UI"),
+        libbonoboui_requirements, NULL,
+        libbonoboui_pre_args_parse, libbonoboui_post_args_parse,
+        NULL, NULL, NULL, NULL, NULL
+};
 
 /*****************************************************************************
  * libgnomeui
  *****************************************************************************/
 
-static void libgnomeui_arg_callback 	(poptContext con,
-					 enum poptCallbackReason reason,
-					 const struct poptOption * opt,
-					 const char * arg,
-					 void * data);
-static void libgnomeui_init_pass	(const GnomeModuleInfo *mod_info);
-static void libgnomeui_class_init	(GnomeProgramClass *klass,
-					 const GnomeModuleInfo *mod_info);
-static void libgnomeui_instance_init	(GnomeProgram *program,
-					 GnomeModuleInfo *mod_info);
-static void libgnomeui_pre_args_parse	(GnomeProgram *app,
-					 GnomeModuleInfo *mod_info);
-static void libgnomeui_post_args_parse	(GnomeProgram *app,
-					 GnomeModuleInfo *mod_info);
-static void libgnomeui_rc_parse		(GnomeProgram *program,
-					 const gchar *command);
-static void libgnomeui_segv_setup	(GnomeProgram *program,
-					 gboolean post_arg_parse);
-
-/* Prototype for a private gnome_stock function */
-void _gnome_stock_icons_init (void);
-
-/* Whether to make noises when the user clicks a button, etc.  We cache it
- * in a boolean rather than querying GConf every time.
- */
-static gboolean use_event_sounds;
-
-/* GConf client for monitoring the event sounds option */
-static GConfClient *gconf_client = NULL;
+static void libgnomeui_arg_callback(poptContext con,
+                                    enum poptCallbackReason reason,
+                                    const struct poptOption * opt,
+                                    const char * arg, void * data);
+static void libgnomeui_init_pass(const GnomeModuleInfo *mod_info);
+static void libgnomeui_class_init(GnomeProgramClass *klass, const GnomeModuleInfo *mod_info);
+static void libgnomeui_instance_init(GnomeProgram *program, GnomeModuleInfo *mod_info);
+static void libgnomeui_pre_args_parse(GnomeProgram *app, GnomeModuleInfo *mod_info);
+static void libgnomeui_post_args_parse(GnomeProgram *app, GnomeModuleInfo *mod_info);
+static void libgnomeui_rc_parse (gchar *command);
+static void libgnomeui_segv_setup(gboolean post_arg_parse);
 
+static GnomeModuleRequirement libgnomeui_requirements[] = {
+        {VERSION, &libgnome_module_info},
+        {VERSION, &libgnomecanvas_module_info},
+        {VERSION, &libbonoboui_module_info},
+        {NULL, NULL}
+};
 
 enum { ARG_DISABLE_CRASH_DIALOG=1, ARG_DISPLAY };
 
 static struct poptOption libgnomeui_options[] = {
-        {NULL, '\0', POPT_ARG_INTL_DOMAIN, GETTEXT_PACKAGE, 0, NULL, NULL},
+        {NULL, '\0', POPT_ARG_INTL_DOMAIN, PACKAGE, 0, NULL, NULL},
 	{NULL, '\0', POPT_ARG_CALLBACK|POPT_CBFLAG_PRE|POPT_CBFLAG_POST,
 	 &libgnomeui_arg_callback, 0, NULL, NULL},
 	{"disable-crash-dialog", '\0', POPT_ARG_NONE, NULL, ARG_DISABLE_CRASH_DIALOG},
@@ -114,38 +128,14 @@ static struct poptOption libgnomeui_options[] = {
 	{NULL, '\0', 0, NULL, 0}
 };
 
-const GnomeModuleInfo *
-libgnomeui_module_info_get (void)
-{
-	static GnomeModuleInfo module_info = {
-		"libgnomeui", VERSION, N_("GNOME GUI Library"),
-		NULL, libgnomeui_instance_init,
-		libgnomeui_pre_args_parse, libgnomeui_post_args_parse,
-		libgnomeui_options,
-		libgnomeui_init_pass, libgnomeui_class_init,
-		NULL, NULL
-	};
-
-	if (module_info.requirements == NULL) {
-		static GnomeModuleRequirement req[6];
-
-		req[0].required_version = "1.101.2";
-		req[0].module_info = LIBBONOBOUI_MODULE;
-
-		req[1].required_version = VERSION;
-		req[1].module_info = gnome_client_module_info_get ();
-
-		req[2].required_version = "1.1.1";
-		req[2].module_info = gnome_gconf_ui_module_info_get ();
-
-		req[3].required_version = NULL;
-		req[3].module_info = NULL;
-
-		module_info.requirements = req;
-	}
-
-	return &module_info;
-}
+GnomeModuleInfo libgnomeui_module_info = {
+        "libgnomeui", VERSION, "GNOME GUI Library",
+        libgnomeui_requirements, libgnomeui_instance_init,
+        libgnomeui_pre_args_parse, libgnomeui_post_args_parse,
+        libgnomeui_options,
+        libgnomeui_init_pass, libgnomeui_class_init,
+        NULL, NULL
+};
 
 typedef struct {
         guint crash_dialog_id;
@@ -211,8 +201,10 @@ libgnomeui_set_property (GObject *object, guint param_id,
 		priv->show_crash_dialog = g_value_get_boolean (value);
 	else if (param_id == cdata->display_id)
 		priv->display = g_strdup (g_value_get_string (value));
-	else
+	else {
+                g_message(G_STRLOC);
                 G_OBJECT_WARN_INVALID_PROPERTY_ID(object, param_id, pspec);
+        }
 }
 
 static void
@@ -245,8 +237,7 @@ libgnomeui_class_init (GnomeProgramClass *klass, const GnomeModuleInfo *mod_info
                 klass,
                 libgnomeui_get_property,
                 libgnomeui_set_property,
-                g_param_spec_string (LIBGNOMEUI_PARAM_DISPLAY, NULL, NULL, 
-				     g_getenv ("DISPLAY"),
+                g_param_spec_string (LIBGNOMEUI_PARAM_DISPLAY, NULL, NULL, NULL,
                                      (G_PARAM_READABLE | G_PARAM_WRITABLE |
                                       G_PARAM_CONSTRUCT_ONLY)));
 
@@ -270,204 +261,63 @@ libgnomeui_instance_init (GnomeProgram *program, GnomeModuleInfo *mod_info)
 static void
 libgnomeui_pre_args_parse(GnomeProgram *app, GnomeModuleInfo *mod_info)
 {
+        gboolean ctype_set;
+        char *ctype, *old_ctype = NULL;
         gboolean do_crash_dialog = TRUE;
         const char *envar;
 
         envar = g_getenv("GNOME_DISABLE_CRASH_DIALOG");
         if(envar)
                 do_crash_dialog = atoi(envar)?FALSE:TRUE;
-	if ( ! do_crash_dialog)
-		g_object_set (G_OBJECT(app),
-			      LIBGNOMEUI_PARAM_CRASH_DIALOG, FALSE,
-			      NULL);
+        g_object_set (G_OBJECT(app), LIBGNOMEUI_PARAM_CRASH_DIALOG,
+                      do_crash_dialog, LIBGNOMEUI_PARAM_DISPLAY,
+                      g_getenv("DISPLAY"), NULL);
 
         if(do_crash_dialog)
-                libgnomeui_segv_setup (app, FALSE);
-}
+                libgnomeui_segv_setup(FALSE);
 
-#ifdef HAVE_ESD
-static gboolean
-relay_gtk_signal(GSignalInvocationHint *hint,
-		 guint n_param_values,
-		 const GValue *param_values,
-		 gchar *signame)
-{
-  char *pieces[3] = {"gtk-events-2", NULL, NULL};
-  static GQuark disable_sound_quark = 0;
-  GObject *object = g_value_get_object (&param_values[0]);
+        /* Begin hack to propogate an en_US locale into Gtk+ if LC_CTYPE=C, so that non-ASCII
+           characters will display for as many people as possible. Related to bug #1979 */
+        ctype = setlocale (LC_CTYPE, NULL);
 
-  pieces[1] = signame;
+        if (!strcmp(ctype, "C")) {
+                old_ctype = g_strdup (g_getenv ("LC_CTYPE"));
+                putenv ("LC_CTYPE=en_US");
+                ctype_set = TRUE;
+        } else
+                ctype_set = FALSE;
 
-  if (!use_event_sounds)
-    return TRUE;
+        gtk_set_locale ();
 
-  if(!disable_sound_quark)
-    disable_sound_quark = g_quark_from_static_string("gnome_disable_sound_events");
+        if (ctype_set) {
+                char *setme;
 
-  if(g_object_get_qdata (object, disable_sound_quark))
-    return TRUE;
+                if (old_ctype) {
+                        setme = g_strconcat ("LC_CTYPE=", old_ctype, NULL);
+                        g_free(old_ctype);
+                } else
+                        setme = "LC_CTYPE";
 
-  if(GTK_IS_WIDGET(object)) {
-    if(!GTK_WIDGET_DRAWABLE(object))
-      return TRUE;
-
-    if(GTK_IS_MENU_ITEM(object) && GTK_MENU_ITEM(object)->submenu)
-      return TRUE;
-  }
-
-  if (gnome_sound_connection_get() < 0)
-    return TRUE;
-
-  gnome_triggers_vdo("", NULL, (const char **)pieces);
-
-  return TRUE;
-}
-
-static void
-initialize_gtk_signal_relay (void)
-{
-	gpointer iter_signames;
-	char *signame;
-	char *ctmp, *ctmp2;
-        static gboolean initialized = FALSE;
-
-        if (initialized)
-                return;
-
-        initialized = TRUE;
-	
-	ctmp = gnome_config_file ("/sound/events/gtk-events-2.soundlist");
-	ctmp2 = g_strconcat ("=", ctmp, "=", NULL);
-	g_free (ctmp);
-	iter_signames = gnome_config_init_iterator_sections (ctmp2);
-	gnome_config_push_prefix (ctmp2);
-	g_free (ctmp2);
-	
-	while ((iter_signames = gnome_config_iterator_next (iter_signames,
-							    &signame, NULL))) {
-		int signums [5];
-		int nsigs, i;
-		gboolean used_signame;
-
-		/*
-		 * XXX this is an incredible hack based on a compile-time
-		 * knowledge of what gtk widgets do what, rather than
-		 * anything based on the info available at runtime.
-		 */
-		if (!strcmp (signame, "activate")) {
-			g_type_class_unref (g_type_class_ref (gtk_menu_item_get_type ()));
-			signums [0] = g_signal_lookup (signame, gtk_menu_item_get_type ());
-			
-			g_type_class_unref (g_type_class_ref (gtk_entry_get_type ()));
-			signums [1] = g_signal_lookup (signame, gtk_entry_get_type ());
-			nsigs = 2;
-		} else if (!strcmp(signame, "toggled")) {
-			g_type_class_unref (g_type_class_ref (gtk_toggle_button_get_type ()));
-			signums [0] = g_signal_lookup (signame,
-							 gtk_toggle_button_get_type ());
-			
-			g_type_class_unref (g_type_class_ref (gtk_check_menu_item_get_type ()));
-			signums [1] = g_signal_lookup (signame,
-							 gtk_check_menu_item_get_type ());
-			nsigs = 2;
-		} else if (!strcmp (signame, "clicked")) {
-			g_type_class_unref (g_type_class_ref (gtk_button_get_type ()));
-			signums [0] = g_signal_lookup (signame, gtk_button_get_type ());
-			nsigs = 1;
-		} else {
-			g_type_class_unref (g_type_class_ref (gtk_widget_get_type ()));
-			signums [0] = g_signal_lookup (signame, gtk_widget_get_type ());
-			nsigs = 1;
-		}
-
-		used_signame = FALSE;
-		for (i = 0; i < nsigs; i++) {
-			if (signums [i] > 0) {
-				g_signal_add_emission_hook (
-                                        signums [i], 0,
-                                        (GSignalEmissionHook) relay_gtk_signal,
-                                        signame, NULL);
-                                used_signame = TRUE;
-                        }
-                }
-
-                if (!used_signame)
-                        g_free (signame);
-	}
-	gnome_config_pop_prefix ();
-}
-
-/* Callback used when the GConf event_sounds key's value changes */
-static void
-event_sounds_changed_cb (GConfClient* client, guint cnxn_id, GConfEntry *entry, gpointer data)
-{
-        gboolean new_use_event_sounds;
-
-        new_use_event_sounds = (gnome_gconf_get_bool ("/desktop/gnome/sound/enable_esd") &&
-                                gnome_gconf_get_bool ("/desktop/gnome/sound/event_sounds"));
-
-        if (new_use_event_sounds && !use_event_sounds)
-                initialize_gtk_signal_relay ();
-
-        use_event_sounds = new_use_event_sounds;
-}
-#endif
-
-static void
-setup_event_listener (void)
-{
-#ifdef HAVE_ESD
-        gconf_client = gconf_client_get_default ();
-        if (!gconf_client)
-                return;
-
-        gconf_client_add_dir (gconf_client, "/desktop/gnome/sound",
-                              GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
-
-        gconf_client_notify_add (gconf_client, "/desktop/gnome/sound/event_sounds",
-                                 event_sounds_changed_cb,
-                                 NULL, NULL, NULL);
-        gconf_client_notify_add (gconf_client, "/desktop/gnome/sound/enable_esd",
-                                 event_sounds_changed_cb,
-                                 NULL, NULL, NULL);
-	
-        use_event_sounds = (gnome_gconf_get_bool ("/desktop/gnome/sound/enable_esd") &&
-                            gnome_gconf_get_bool ("/desktop/gnome/sound/event_sounds"));
-
-        if (use_event_sounds)
-                initialize_gtk_signal_relay ();
-#endif
+                putenv (setme);
+        }
+        /* End hack */
 }
 
 static void
 libgnomeui_post_args_parse(GnomeProgram *program, GnomeModuleInfo *mod_info)
 {
-        GnomeProgramPrivate_libgnomeui *priv;
-        gchar *filename;
+        GnomeProgramPrivate_libgnomeui *priv = g_new0(GnomeProgramPrivate_libgnomeui, 1);
 
         gnome_type_init();
-        libgnomeui_rc_parse (program, g_get_prgname ());
+        // #warning FIXME: here... gtk_rc ...
+        libgnomeui_rc_parse(program_invocation_name);
 
-        libgnomeui_segv_setup (program, TRUE);
+        libgnomeui_segv_setup(TRUE);
 
         priv = g_object_get_qdata(G_OBJECT(program), quark_gnome_program_private_libgnomeui);
         priv->constructed = TRUE;
 
-        /* load the accelerators */
-        filename = g_build_filename (gnome_user_accels_dir_get (),
-                                     gnome_program_get_app_id (program),
-                                     NULL);
-        gtk_accel_map_load (filename);
-        g_free (filename);
-
-	bindtextdomain (GETTEXT_PACKAGE, GNOMEUILOCALEDIR);
-#ifdef HAVE_BIND_TEXTDOMAIN_CODESET
-	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
-#endif
-
-        _gnome_stock_icons_init ();
-
-        setup_event_listener ();
+        init_gnome_stock_icons ();
 }
 
 static void
@@ -476,8 +326,7 @@ libgnomeui_arg_callback(poptContext con,
                         const struct poptOption * opt,
                         const char * arg, void * data)
 {
-        GnomeProgram *program = g_dataset_get_data (con, "GnomeProgram");
-	g_assert (program != NULL);
+        GnomeProgram *program = gnome_program_get ();
 
         switch(reason) {
         case POPT_CALLBACK_REASON_OPTION:
@@ -511,14 +360,14 @@ libgnomeui_arg_callback(poptContext con,
  * It provides good consistancy (you always know the rc file will be
  * the same name as the executable), and it's easy for the programmer.
  * 
- * If you don't like it.. give me a good reason.
+ * If you don't like it.. give me a good reason.  Symlin
  */
 static void
-libgnomeui_rc_parse (GnomeProgram *program, const gchar *command)
+libgnomeui_rc_parse (gchar *command)
 {
 	gint i;
 	gint buf_len;
-	const gchar *buf = NULL;
+	gchar *buf = NULL;
 	gchar *file;
 	gchar *apprc;
 	
@@ -540,9 +389,9 @@ libgnomeui_rc_parse (GnomeProgram *program, const gchar *command)
 	/* <gnomedatadir>/gtkrc */
         file = gnome_program_locate_file (gnome_program_get (),
                                           GNOME_FILE_DOMAIN_DATADIR,
-                                          "gtkrc-2.0", TRUE, NULL);
+                                          "gtkrc", TRUE, NULL);
   	if (file) {
-  		gtk_rc_parse (file); 
+  		gtk_rc_add_default_file (file); 
 		g_free (file);
 	}
 
@@ -551,21 +400,21 @@ libgnomeui_rc_parse (GnomeProgram *program, const gchar *command)
                                           GNOME_FILE_DOMAIN_DATADIR,
                                           apprc, TRUE, NULL);
 	if (file) {
-                gtk_rc_parse (file);
+                gtk_rc_add_default_file (file);
                 g_free (file);
         }
 	
 	/* ~/.gnome/gtkrc */
-	file = gnome_util_home_file("gtkrc-2.0");
+	file = gnome_util_home_file("gtkrc");
 	if (file) {
-		gtk_rc_parse (file);
+		gtk_rc_add_default_file (file);
 		g_free (file);
 	}
 	
 	/* ~/.gnome/<progname> */
 	file = gnome_util_home_file(apprc);
 	if (file) {
-		gtk_rc_parse (file);
+		gtk_rc_add_default_file (file);
 		g_free (file);
 	}
 }
@@ -574,7 +423,7 @@ libgnomeui_rc_parse (GnomeProgram *program, const gchar *command)
 static void libgnomeui_segv_handle(int signum);
 
 static void
-libgnomeui_segv_setup (GnomeProgram *program, gboolean post_arg_parse)
+libgnomeui_segv_setup(gboolean post_arg_parse)
 {
         static struct sigaction *setptr;
         struct sigaction sa;
@@ -582,24 +431,23 @@ libgnomeui_segv_setup (GnomeProgram *program, gboolean post_arg_parse)
         GValue value = { 0, };
 
         g_value_init (&value, G_TYPE_BOOLEAN);
-        g_object_get_property (G_OBJECT (program),
+        g_object_get_property (G_OBJECT (gnome_program_get()),
                                LIBGNOMEUI_PARAM_CRASH_DIALOG, &value);
         do_crash_dialog = g_value_get_boolean (&value);
         g_value_unset (&value);
 
+        memset(&sa, 0, sizeof(sa));
+
+        setptr = &sa;
         if(do_crash_dialog) {
-                memset(&sa, 0, sizeof(sa));
-                setptr = &sa;
-
                 sa.sa_handler = (gpointer)libgnomeui_segv_handle;
-
-                sigaction(SIGSEGV, setptr, NULL);
-                sigaction(SIGABRT, setptr, NULL);
-                sigaction(SIGTRAP, setptr, NULL);
-                sigaction(SIGFPE, setptr, NULL);
-                sigaction(SIGBUS, setptr, NULL);
+        } else {
+                sa.sa_handler = SIG_DFL;
         }
 
+        sigaction(SIGSEGV, setptr, NULL);
+        sigaction(SIGFPE, setptr, NULL);
+        sigaction(SIGBUS, setptr, NULL);
 }
 
 static void libgnomeui_segv_handle(int signum)
@@ -624,19 +472,7 @@ static void libgnomeui_segv_handle(int signum)
 
         gdk_flush();
         
-	pid = fork();
-
-	if (pid < 0) {
-		/* Eeeek! Can't show dialog */
-                fprintf (stderr, _("Segmentation fault!\n"
-				   "Cannot display crash dialog\n"));
-
-                /* Don't use app attributes here - a lot of things are probably hosed */
-		if (g_getenv ("GNOME_DUMP_CORE"))
-	                abort ();
-
-		_exit(1);
-	} else if (pid > 0) {
+	if ((pid = fork())) {
                 /* Wait for user to see the dialog, then exit. */
                 /* Why wait at all? Because we want to allow people to attach to the
 		   process */
@@ -650,7 +486,7 @@ static void libgnomeui_segv_handle(int signum)
 	                abort ();
 
 		_exit(1);
-	} else /* pid == 0 */ {
+	} else {
                 GnomeProgram *program;
 		char buf[32];
 
@@ -659,13 +495,11 @@ static void libgnomeui_segv_handle(int signum)
                 program = gnome_program_get();
 
 		/* Child process */
-		execl (GNOMEUISERVERDIR "/gnome_segv2", GNOMEUISERVERDIR "/gnome_segv",
-		       g_get_prgname (), buf,
-		       gnome_program_get_app_version (program), NULL);
+		execl(GNOMEUIBINDIR "/gnome_segv", GNOMEUIBINDIR "/gnome_segv",
+		      gnome_program_get_name(program), buf, gnome_program_get_version(program), NULL);
 
-                execlp ("gnome_segv2", "gnome_segv2",
-			g_get_prgname (), buf,
-			gnome_program_get_app_version (program), NULL);
+                execlp("gnome_segv", "gnome_segv", gnome_program_get_name(program), buf,
+                       gnome_program_get_version(program), NULL);
 
                 _exit(99);
 	}
@@ -676,49 +510,25 @@ static void libgnomeui_segv_handle(int signum)
 /* #warning "Solve the sound events situation" */
 
 /* backwards compat */
-/**
- * gnome_init_with_popt_table:
- * @app_id: Application id.
- * @app_version: Application version.
- * @argc: argument count (for example argc as received by main)
- * @argv: argument vector (for example argv as received by main)
- * @options: poptOption table with options to parse
- * @flags: popt flags.
- * @return_ctx: if non-NULL, the popt context is returned here.
- *
- * Initializes the application.  This sets up all of the GNOME
- * internals and prepares them (imlib, gdk, session-management, triggers,
- * sound, user preferences).
- *
- * Unlike #gnome_init, with #gnome_init_with_popt_table you can provide
- * a table of popt options (popt is the command line argument parsing
- * library).
- *
- * Deprecated, use #gnome_program_init with the LIBGNOMEUI_MODULE.
- *
- * Returns: 0 (always)
- */
-int
-gnome_init_with_popt_table (const char *app_id,
-			    const char *app_version,
-			    int argc, char **argv,
-			    const struct poptOption *options,
-			    int flags,
-			    poptContext *return_ctx)
+int gnome_init_with_popt_table(const char *app_id,
+			       const char *app_version,
+			       int argc, char **argv,
+			       const struct poptOption *options,
+			       int flags,
+			       poptContext *return_ctx)
 {
-	GnomeProgram *program;
-        program = gnome_program_init (app_id, app_version,
-				      LIBGNOMEUI_MODULE,
-				      argc, argv,
-				      GNOME_PARAM_POPT_TABLE, options,
-				      GNOME_PARAM_POPT_FLAGS, flags,
-				      NULL);
+        gnome_program_init(app_id, app_version,
+                           &libgnomeui_module_info,
+                           argc, argv,
+                           GNOME_PARAM_POPT_TABLE, options,
+                           GNOME_PARAM_POPT_FLAGS, flags,
+                           NULL);
 
         if(return_ctx) {
                 GValue value = { 0, };
 
                 g_value_init (&value, G_TYPE_POINTER);
-                g_object_get_property (G_OBJECT (program),
+                g_object_get_property (G_OBJECT (gnome_program_get()),
                                        GNOME_PARAM_POPT_CONTEXT, &value);
                 *return_ctx = g_value_peek_pointer (&value);
                 g_value_unset (&value);
@@ -727,8 +537,4 @@ gnome_init_with_popt_table (const char *app_id,
         return 0;
 }
 
-const GnomeModuleInfo *
-gnome_gtk_module_info_get (void)
-{
-        return bonobo_ui_gtk_module_info_get ();
-}
+
