@@ -26,8 +26,8 @@
 
 /* needed for sigaction and friends under 'gcc -ansi -pedantic' on 
  * GNU/Linux */
-#ifndef _GNU_SOURCE
-#  define _GNU_SOURCE 1
+#ifndef _POSIX_SOURCE
+#  define _POSIX_SOURCE 1
 #endif
 #include <sys/types.h>
 #include <sys/wait.h>
@@ -36,15 +36,12 @@
 
 #include <stdlib.h>
 #include <unistd.h>
-#include <libgnome/libgnome.h>
-#include <libgnomeui/libgnomeui.h>
+#include <libgnome.h>
+#include <libgnomeui.h>
 #include <signal.h>
 #include <string.h>
 #include <stdio.h>
 
-/* Must be before all other gnome includes!! */
-#include "gnome-i18nP.h"
-
 enum {
   RESPONSE_NULL,
   RESPONSE_BUG_BUDDY,
@@ -74,13 +71,13 @@ int main(int argc, char *argv[])
   sigaction(SIGSEGV, &sa, NULL);
 
 
-  bindtextdomain (GETTEXT_PACKAGE, GNOMEUILOCALEDIR);
-  textdomain (GETTEXT_PACKAGE);
+  bindtextdomain (PACKAGE, GNOMEUILOCALEDIR);
+  textdomain (PACKAGE);
 
   /* in case gnome-session is segfaulting :-) */
   gnome_client_disable_master_connection();
   
-  gnome_init_with_popt_table("gnome_segv2", VERSION, argc, argv, NULL, 0, &ctx);
+  gnome_init_with_popt_table("gnome_segv", VERSION, argc, argv, NULL, 0, &ctx);
 
   memset(&sa, 0, sizeof(sa));
   sa.sa_handler = SIG_IGN;
@@ -90,11 +87,6 @@ int main(int argc, char *argv[])
   if (args && args[0] && args[1])
     {
       char *base = g_path_get_basename (args[0]);
-      gsize bytes_read;
-      gsize bytes_written;
-      const char *utfstr = g_strsignal (atoi (args[1]));
-      char *progstr = g_locale_to_utf8 (args[0], -1, &bytes_read, &bytes_written, NULL);
-      
       if (strcmp(base, "gnome-session") == 0)
         {
           msg = g_strdup_printf(_("The GNOME Session Manager (process %d) has crashed\n"
@@ -102,36 +94,33 @@ int main(int argc, char *argv[])
                                   "When you close this dialog, all applications will close "
                                   "and your session will exit.\n"
                                   "Please save all your files before closing this dialog."),
-                                getppid(), utfstr);
+                                getppid(), g_strsignal(atoi(args[1])));
           bb_sm_disable = 1;
         }
       else
         {
           msg = g_strdup_printf(_("Application \"%s\" (process %d) has crashed\ndue to a fatal error.\n(%s)"),
-                                progstr, getppid(), utfstr);
+                                args[0], getppid(), g_strsignal(atoi(args[1])));
         }
-      g_free(progstr);
       g_free(base);
       if(args[2])
 	app_version = args[2];
     }
   else
     {
-      gsize bytes_read;
-      gsize bytes_written;
-      gchar* localestr=g_locale_from_utf8(_("Usage: gnome_segv2 appname signum\n"),-1,&bytes_read,&bytes_written,NULL);
-      fprintf(stderr, localestr);
-      g_free(localestr);
+      fprintf(stderr, _("Usage: gnome_segv appname signum\n"));
       return 1;
     }
   appname = g_strdup(args[0]);
+
   mainwin = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
                                     GTK_MESSAGE_ERROR,
                                     GTK_BUTTONS_CLOSE,
                                     msg);
-  g_free(msg);
+
+
   
-  bug_buddy_path = g_find_program_in_path ("bug-buddy");
+  bug_buddy_path = gnome_is_program_in_path ("bug-buddy");
   if (bug_buddy_path != NULL)
     {
       gtk_dialog_add_button(GTK_DIALOG(mainwin),
@@ -142,7 +131,7 @@ int main(int argc, char *argv[])
   debugger = g_getenv("GNOME_DEBUGGER");
   if (debugger && strlen(debugger)>0)
   {
-    debugger_path = g_find_program_in_path (debugger);
+    debugger_path = gnome_is_program_in_path (debugger);
     if (debugger_path != NULL)
       {
         gtk_dialog_add_button(GTK_DIALOG(mainwin),
@@ -164,6 +153,7 @@ int main(int argc, char *argv[])
   gtk_widget_show(urlbtn);
   gtk_container_add(GTK_CONTAINER(GTK_DIALOG(mainwin)->vbox), urlbtn);
 
+  g_free(msg);
 
   res = gtk_dialog_run(GTK_DIALOG(mainwin));
 
@@ -178,11 +168,7 @@ int main(int argc, char *argv[])
                                  bug_buddy_path, appname, getppid(), 
                                  app_version, bb_sm_disable 
                                  ? "--sm-disable" : "");
-#ifdef HAVE_SETENV
-      setenv ("BUG_BUDDY_GNOME_VERSION", "2.0 (" VERSION ")", 1);
-#else
-      putenv ("BUG_BUDDY_GNOME_VERSION=2.0 (" VERSION ")");
-#endif
+
       retval = system(exec_str);
       g_free(exec_str);
       if (retval == -1 || retval == 127)
