@@ -1,109 +1,13 @@
 
 /* Generated data (by glib-mkenums) */
 
+#include <gobject/genums.h>
 #include "libgnomeui.h"
 
 #include "gnometypebuiltins.h"
 
 
 
-/* enumerations from "gnome-app-helper.h" */
-static const GEnumValue _gnome_ui_info_type_values[] = {
-  { GNOME_APP_UI_ENDOFINFO, "GNOME_APP_UI_ENDOFINFO", "endofinfo" },
-  { GNOME_APP_UI_ITEM, "GNOME_APP_UI_ITEM", "item" },
-  { GNOME_APP_UI_TOGGLEITEM, "GNOME_APP_UI_TOGGLEITEM", "toggleitem" },
-  { GNOME_APP_UI_RADIOITEMS, "GNOME_APP_UI_RADIOITEMS", "radioitems" },
-  { GNOME_APP_UI_SUBTREE, "GNOME_APP_UI_SUBTREE", "subtree" },
-  { GNOME_APP_UI_SEPARATOR, "GNOME_APP_UI_SEPARATOR", "separator" },
-  { GNOME_APP_UI_HELP, "GNOME_APP_UI_HELP", "help" },
-  { GNOME_APP_UI_BUILDER_DATA, "GNOME_APP_UI_BUILDER_DATA", "builder-data" },
-  { GNOME_APP_UI_ITEM_CONFIGURABLE, "GNOME_APP_UI_ITEM_CONFIGURABLE", "item-configurable" },
-  { GNOME_APP_UI_SUBTREE_STOCK, "GNOME_APP_UI_SUBTREE_STOCK", "subtree-stock" },
-  { GNOME_APP_UI_INCLUDE, "GNOME_APP_UI_INCLUDE", "include" },
-  { 0, NULL, NULL }
-};
-
-GType
-gnome_ui_info_type_get_type (void)
-{
-  static GType type = 0;
-
-  if (!type)
-    type = g_enum_register_static ("GnomeUIInfoType", _gnome_ui_info_type_values);
-
-  return type;
-}
-
-
-static const GEnumValue _gnome_ui_info_configurable_types_values[] = {
-  { GNOME_APP_CONFIGURABLE_ITEM_NEW, "GNOME_APP_CONFIGURABLE_ITEM_NEW", "new" },
-  { GNOME_APP_CONFIGURABLE_ITEM_OPEN, "GNOME_APP_CONFIGURABLE_ITEM_OPEN", "open" },
-  { GNOME_APP_CONFIGURABLE_ITEM_SAVE, "GNOME_APP_CONFIGURABLE_ITEM_SAVE", "save" },
-  { GNOME_APP_CONFIGURABLE_ITEM_SAVE_AS, "GNOME_APP_CONFIGURABLE_ITEM_SAVE_AS", "save-as" },
-  { GNOME_APP_CONFIGURABLE_ITEM_REVERT, "GNOME_APP_CONFIGURABLE_ITEM_REVERT", "revert" },
-  { GNOME_APP_CONFIGURABLE_ITEM_PRINT, "GNOME_APP_CONFIGURABLE_ITEM_PRINT", "print" },
-  { GNOME_APP_CONFIGURABLE_ITEM_PRINT_SETUP, "GNOME_APP_CONFIGURABLE_ITEM_PRINT_SETUP", "print-setup" },
-  { GNOME_APP_CONFIGURABLE_ITEM_CLOSE, "GNOME_APP_CONFIGURABLE_ITEM_CLOSE", "close" },
-  { GNOME_APP_CONFIGURABLE_ITEM_QUIT, "GNOME_APP_CONFIGURABLE_ITEM_QUIT", "quit" },
-  { GNOME_APP_CONFIGURABLE_ITEM_CUT, "GNOME_APP_CONFIGURABLE_ITEM_CUT", "cut" },
-  { GNOME_APP_CONFIGURABLE_ITEM_COPY, "GNOME_APP_CONFIGURABLE_ITEM_COPY", "copy" },
-  { GNOME_APP_CONFIGURABLE_ITEM_PASTE, "GNOME_APP_CONFIGURABLE_ITEM_PASTE", "paste" },
-  { GNOME_APP_CONFIGURABLE_ITEM_CLEAR, "GNOME_APP_CONFIGURABLE_ITEM_CLEAR", "clear" },
-  { GNOME_APP_CONFIGURABLE_ITEM_UNDO, "GNOME_APP_CONFIGURABLE_ITEM_UNDO", "undo" },
-  { GNOME_APP_CONFIGURABLE_ITEM_REDO, "GNOME_APP_CONFIGURABLE_ITEM_REDO", "redo" },
-  { GNOME_APP_CONFIGURABLE_ITEM_FIND, "GNOME_APP_CONFIGURABLE_ITEM_FIND", "find" },
-  { GNOME_APP_CONFIGURABLE_ITEM_FIND_AGAIN, "GNOME_APP_CONFIGURABLE_ITEM_FIND_AGAIN", "find-again" },
-  { GNOME_APP_CONFIGURABLE_ITEM_REPLACE, "GNOME_APP_CONFIGURABLE_ITEM_REPLACE", "replace" },
-  { GNOME_APP_CONFIGURABLE_ITEM_PROPERTIES, "GNOME_APP_CONFIGURABLE_ITEM_PROPERTIES", "properties" },
-  { GNOME_APP_CONFIGURABLE_ITEM_PREFERENCES, "GNOME_APP_CONFIGURABLE_ITEM_PREFERENCES", "preferences" },
-  { GNOME_APP_CONFIGURABLE_ITEM_ABOUT, "GNOME_APP_CONFIGURABLE_ITEM_ABOUT", "about" },
-  { GNOME_APP_CONFIGURABLE_ITEM_SELECT_ALL, "GNOME_APP_CONFIGURABLE_ITEM_SELECT_ALL", "select-all" },
-  { GNOME_APP_CONFIGURABLE_ITEM_NEW_WINDOW, "GNOME_APP_CONFIGURABLE_ITEM_NEW_WINDOW", "new-window" },
-  { GNOME_APP_CONFIGURABLE_ITEM_CLOSE_WINDOW, "GNOME_APP_CONFIGURABLE_ITEM_CLOSE_WINDOW", "close-window" },
-  { GNOME_APP_CONFIGURABLE_ITEM_NEW_GAME, "GNOME_APP_CONFIGURABLE_ITEM_NEW_GAME", "new-game" },
-  { GNOME_APP_CONFIGURABLE_ITEM_PAUSE_GAME, "GNOME_APP_CONFIGURABLE_ITEM_PAUSE_GAME", "pause-game" },
-  { GNOME_APP_CONFIGURABLE_ITEM_RESTART_GAME, "GNOME_APP_CONFIGURABLE_ITEM_RESTART_GAME", "restart-game" },
-  { GNOME_APP_CONFIGURABLE_ITEM_UNDO_MOVE, "GNOME_APP_CONFIGURABLE_ITEM_UNDO_MOVE", "undo-move" },
-  { GNOME_APP_CONFIGURABLE_ITEM_REDO_MOVE, "GNOME_APP_CONFIGURABLE_ITEM_REDO_MOVE", "redo-move" },
-  { GNOME_APP_CONFIGURABLE_ITEM_HINT, "GNOME_APP_CONFIGURABLE_ITEM_HINT", "hint" },
-  { GNOME_APP_CONFIGURABLE_ITEM_SCORES, "GNOME_APP_CONFIGURABLE_ITEM_SCORES", "scores" },
-  { GNOME_APP_CONFIGURABLE_ITEM_END_GAME, "GNOME_APP_CONFIGURABLE_ITEM_END_GAME", "end-game" },
-  { 0, NULL, NULL }
-};
-
-GType
-gnome_ui_info_configurable_types_get_type (void)
-{
-  static GType type = 0;
-
-  if (!type)
-    type = g_enum_register_static ("GnomeUIInfoConfigurableTypes", _gnome_ui_info_configurable_types_values);
-
-  return type;
-}
-
-
-static const GEnumValue _gnome_ui_pixmap_type_values[] = {
-  { GNOME_APP_PIXMAP_NONE, "GNOME_APP_PIXMAP_NONE", "none" },
-  { GNOME_APP_PIXMAP_STOCK, "GNOME_APP_PIXMAP_STOCK", "stock" },
-  { GNOME_APP_PIXMAP_DATA, "GNOME_APP_PIXMAP_DATA", "data" },
-  { GNOME_APP_PIXMAP_FILENAME, "GNOME_APP_PIXMAP_FILENAME", "filename" },
-  { 0, NULL, NULL }
-};
-
-GType
-gnome_ui_pixmap_type_get_type (void)
-{
-  static GType type = 0;
-
-  if (!type)
-    type = g_enum_register_static ("GnomeUIPixmapType", _gnome_ui_pixmap_type_values);
-
-  return type;
-}
-
-
-
 /* enumerations from "gnome-client.h" */
 static const GEnumValue _gnome_interact_style_values[] = {
   { GNOME_INTERACT_NONE, "GNOME_INTERACT_NONE", "none" },
@@ -267,28 +171,6 @@ gnome_edge_position_get_type (void)
 
 
 
-/* enumerations from "gnome-font-picker.h" */
-static const GEnumValue _gnome_font_picker_mode_values[] = {
-  { GNOME_FONT_PICKER_MODE_PIXMAP, "GNOME_FONT_PICKER_MODE_PIXMAP", "pixmap" },
-  { GNOME_FONT_PICKER_MODE_FONT_INFO, "GNOME_FONT_PICKER_MODE_FONT_INFO", "font-info" },
-  { GNOME_FONT_PICKER_MODE_USER_WIDGET, "GNOME_FONT_PICKER_MODE_USER_WIDGET", "user-widget" },
-  { GNOME_FONT_PICKER_MODE_UNKNOWN, "GNOME_FONT_PICKER_MODE_UNKNOWN", "unknown" },
-  { 0, NULL, NULL }
-};
-
-GType
-gnome_font_picker_mode_get_type (void)
-{
-  static GType type = 0;
-
-  if (!type)
-    type = g_enum_register_static ("GnomeFontPickerMode", _gnome_font_picker_mode_values);
-
-  return type;
-}
-
-
-
 /* enumerations from "gnome-icon-list.h" */
 static const GEnumValue _gnome_icon_list_mode_values[] = {
   { GNOME_ICON_LIST_ICONS, "GNOME_ICON_LIST_ICONS", "icons" },
@@ -310,28 +192,6 @@ gnome_icon_list_mode_get_type (void)
 
 
 
-/* enumerations from "gnome-mdi.h" */
-static const GEnumValue _gnome_mdi_mode_values[] = {
-  { GNOME_MDI_NOTEBOOK, "GNOME_MDI_NOTEBOOK", "notebook" },
-  { GNOME_MDI_TOPLEVEL, "GNOME_MDI_TOPLEVEL", "toplevel" },
-  { GNOME_MDI_MODAL, "GNOME_MDI_MODAL", "modal" },
-  { GNOME_MDI_DEFAULT_MODE, "GNOME_MDI_DEFAULT_MODE", "default-mode" },
-  { 0, NULL, NULL }
-};
-
-GType
-gnome_mdi_mode_get_type (void)
-{
-  static GType type = 0;
-
-  if (!type)
-    type = g_enum_register_static ("GnomeMDIMode", _gnome_mdi_mode_values);
-
-  return type;
-}
-
-
-
 /* enumerations from "gnome-types.h" */
 static const GEnumValue _gnome_preferences_type_values[] = {
   { GNOME_PREFERENCES_NEVER, "GNOME_PREFERENCES_NEVER", "never" },
@@ -353,5 +213,138 @@ gnome_preferences_type_get_type (void)
 
 
 
+/* enumerations from "gnome-winhints.h" */
+static const GEnumValue _gnome_win_layer_values[] = {
+  { WIN_LAYER_DESKTOP, "WIN_LAYER_DESKTOP", "desktop" },
+  { WIN_LAYER_BELOW, "WIN_LAYER_BELOW", "below" },
+  { WIN_LAYER_NORMAL, "WIN_LAYER_NORMAL", "normal" },
+  { WIN_LAYER_ONTOP, "WIN_LAYER_ONTOP", "ontop" },
+  { WIN_LAYER_DOCK, "WIN_LAYER_DOCK", "dock" },
+  { WIN_LAYER_ABOVE_DOCK, "WIN_LAYER_ABOVE_DOCK", "above-dock" },
+  { 0, NULL, NULL }
+};
+
+GType
+gnome_win_layer_get_type (void)
+{
+  static GType type = 0;
+
+  if (!type)
+    type = g_enum_register_static ("GnomeWinLayer", _gnome_win_layer_values);
+
+  return type;
+}
+
+
+static const GFlagsValue _gnome_win_state_values[] = {
+  { WIN_STATE_STICKY, "WIN_STATE_STICKY", "sticky" },
+  { WIN_STATE_MINIMIZED, "WIN_STATE_MINIMIZED", "minimized" },
+  { WIN_STATE_MAXIMIZED_VERT, "WIN_STATE_MAXIMIZED_VERT", "maximized-vert" },
+  { WIN_STATE_MAXIMIZED_HORIZ, "WIN_STATE_MAXIMIZED_HORIZ", "maximized-horiz" },
+  { WIN_STATE_HIDDEN, "WIN_STATE_HIDDEN", "hidden" },
+  { WIN_STATE_SHADED, "WIN_STATE_SHADED", "shaded" },
+  { WIN_STATE_HID_WORKSPACE, "WIN_STATE_HID_WORKSPACE", "hid-workspace" },
+  { WIN_STATE_HID_TRANSIENT, "WIN_STATE_HID_TRANSIENT", "hid-transient" },
+  { WIN_STATE_FIXED_POSITION, "WIN_STATE_FIXED_POSITION", "fixed-position" },
+  { WIN_STATE_ARRANGE_IGNORE, "WIN_STATE_ARRANGE_IGNORE", "arrange-ignore" },
+  { 0, NULL, NULL }
+};
+
+GType
+gnome_win_state_get_type (void)
+{
+  static GType type = 0;
+
+  if (!type)
+    type = g_flags_register_static ("GnomeWinState", _gnome_win_state_values);
+
+  return type;
+}
+
+
+static const GFlagsValue _gnome_win_hints_values[] = {
+  { WIN_HINTS_SKIP_FOCUS, "WIN_HINTS_SKIP_FOCUS", "skip-focus" },
+  { WIN_HINTS_SKIP_WINLIST, "WIN_HINTS_SKIP_WINLIST", "skip-winlist" },
+  { WIN_HINTS_SKIP_TASKBAR, "WIN_HINTS_SKIP_TASKBAR", "skip-taskbar" },
+  { WIN_HINTS_GROUP_TRANSIENT, "WIN_HINTS_GROUP_TRANSIENT", "group-transient" },
+  { WIN_HINTS_FOCUS_ON_CLICK, "WIN_HINTS_FOCUS_ON_CLICK", "focus-on-click" },
+  { WIN_HINTS_DO_NOT_COVER, "WIN_HINTS_DO_NOT_COVER", "do-not-cover" },
+  { 0, NULL, NULL }
+};
+
+GType
+gnome_win_hints_get_type (void)
+{
+  static GType type = 0;
+
+  if (!type)
+    type = g_flags_register_static ("GnomeWinHints", _gnome_win_hints_values);
+
+  return type;
+}
+
+
+static const GEnumValue _gnome_win_app_state_values[] = {
+  { WIN_APP_STATE_NONE, "WIN_APP_STATE_NONE", "none" },
+  { WIN_APP_STATE_ACTIVE1, "WIN_APP_STATE_ACTIVE1", "active1" },
+  { WIN_APP_STATE_ACTIVE2, "WIN_APP_STATE_ACTIVE2", "active2" },
+  { WIN_APP_STATE_ERROR1, "WIN_APP_STATE_ERROR1", "error1" },
+  { WIN_APP_STATE_ERROR2, "WIN_APP_STATE_ERROR2", "error2" },
+  { WIN_APP_STATE_FATAL_ERROR1, "WIN_APP_STATE_FATAL_ERROR1", "fatal-error1" },
+  { WIN_APP_STATE_FATAL_ERROR2, "WIN_APP_STATE_FATAL_ERROR2", "fatal-error2" },
+  { WIN_APP_STATE_IDLE1, "WIN_APP_STATE_IDLE1", "idle1" },
+  { WIN_APP_STATE_IDLE2, "WIN_APP_STATE_IDLE2", "idle2" },
+  { WIN_APP_STATE_WAITING1, "WIN_APP_STATE_WAITING1", "waiting1" },
+  { WIN_APP_STATE_WAITING2, "WIN_APP_STATE_WAITING2", "waiting2" },
+  { WIN_APP_STATE_WORKING1, "WIN_APP_STATE_WORKING1", "working1" },
+  { WIN_APP_STATE_WORKING2, "WIN_APP_STATE_WORKING2", "working2" },
+  { WIN_APP_STATE_NEED_USER_INPUT1, "WIN_APP_STATE_NEED_USER_INPUT1", "need-user-input1" },
+  { WIN_APP_STATE_NEED_USER_INPUT2, "WIN_APP_STATE_NEED_USER_INPUT2", "need-user-input2" },
+  { WIN_APP_STATE_STRUGGLING1, "WIN_APP_STATE_STRUGGLING1", "struggling1" },
+  { WIN_APP_STATE_STRUGGLING2, "WIN_APP_STATE_STRUGGLING2", "struggling2" },
+  { WIN_APP_STATE_DISK_TRAFFIC1, "WIN_APP_STATE_DISK_TRAFFIC1", "disk-traffic1" },
+  { WIN_APP_STATE_DISK_TRAFFIC2, "WIN_APP_STATE_DISK_TRAFFIC2", "disk-traffic2" },
+  { WIN_APP_STATE_NETWORK_TRAFFIC1, "WIN_APP_STATE_NETWORK_TRAFFIC1", "network-traffic1" },
+  { WIN_APP_STATE_NETWORK_TRAFFIC2, "WIN_APP_STATE_NETWORK_TRAFFIC2", "network-traffic2" },
+  { WIN_APP_STATE_OVERLOADED1, "WIN_APP_STATE_OVERLOADED1", "overloaded1" },
+  { WIN_APP_STATE_OVERLOADED2, "WIN_APP_STATE_OVERLOADED2", "overloaded2" },
+  { WIN_APP_STATE_PERCENT000_1, "WIN_APP_STATE_PERCENT000_1", "percent000-1" },
+  { WIN_APP_STATE_PERCENT000_2, "WIN_APP_STATE_PERCENT000_2", "percent000-2" },
+  { WIN_APP_STATE_PERCENT010_1, "WIN_APP_STATE_PERCENT010_1", "percent010-1" },
+  { WIN_APP_STATE_PERCENT010_2, "WIN_APP_STATE_PERCENT010_2", "percent010-2" },
+  { WIN_APP_STATE_PERCENT020_1, "WIN_APP_STATE_PERCENT020_1", "percent020-1" },
+  { WIN_APP_STATE_PERCENT020_2, "WIN_APP_STATE_PERCENT020_2", "percent020-2" },
+  { WIN_APP_STATE_PERCENT030_1, "WIN_APP_STATE_PERCENT030_1", "percent030-1" },
+  { WIN_APP_STATE_PERCENT030_2, "WIN_APP_STATE_PERCENT030_2", "percent030-2" },
+  { WIN_APP_STATE_PERCENT040_1, "WIN_APP_STATE_PERCENT040_1", "percent040-1" },
+  { WIN_APP_STATE_PERCENT040_2, "WIN_APP_STATE_PERCENT040_2", "percent040-2" },
+  { WIN_APP_STATE_PERCENT050_1, "WIN_APP_STATE_PERCENT050_1", "percent050-1" },
+  { WIN_APP_STATE_PERCENT050_2, "WIN_APP_STATE_PERCENT050_2", "percent050-2" },
+  { WIN_APP_STATE_PERCENT060_1, "WIN_APP_STATE_PERCENT060_1", "percent060-1" },
+  { WIN_APP_STATE_PERCENT060_2, "WIN_APP_STATE_PERCENT060_2", "percent060-2" },
+  { WIN_APP_STATE_PERCENT070_1, "WIN_APP_STATE_PERCENT070_1", "percent070-1" },
+  { WIN_APP_STATE_PERCENT070_2, "WIN_APP_STATE_PERCENT070_2", "percent070-2" },
+  { WIN_APP_STATE_PERCENT080_1, "WIN_APP_STATE_PERCENT080_1", "percent080-1" },
+  { WIN_APP_STATE_PERCENT080_2, "WIN_APP_STATE_PERCENT080_2", "percent080-2" },
+  { WIN_APP_STATE_PERCENT090_1, "WIN_APP_STATE_PERCENT090_1", "percent090-1" },
+  { WIN_APP_STATE_PERCENT090_2, "WIN_APP_STATE_PERCENT090_2", "percent090-2" },
+  { WIN_APP_STATE_PERCENT100_1, "WIN_APP_STATE_PERCENT100_1", "percent100-1" },
+  { WIN_APP_STATE_PERCENT100_2, "WIN_APP_STATE_PERCENT100_2", "percent100-2" },
+  { 0, NULL, NULL }
+};
+
+GType
+gnome_win_app_state_get_type (void)
+{
+  static GType type = 0;
+
+  if (!type)
+    type = g_enum_register_static ("GnomeWinAppState", _gnome_win_app_state_values);
+
+  return type;
+}
+
+
+
 /* Generated data ends here */
 
