@@ -29,12 +29,6 @@
 
 
 #include <libgnomeui/gnome-uidefs.h>
-
-#include <libgnomeui/gnome-about.h>
-#include <libgnomeui/gnome-app.h>
-#include <libgnomeui/gnome-app-helper.h>
-#include <libgnomeui/gnome-app-util.h>
-#include <libgnomeui/gnome-appbar.h>
 #include <libgnomecanvas/gnome-canvas.h>
 #include <libgnomecanvas/gnome-canvas-pixbuf.h>
 #include <libgnomecanvas/gnome-canvas-line.h>
@@ -45,36 +39,28 @@
 #include <libgnomecanvas/gnome-canvas-widget.h>
 #include <libgnomeui/gnome-color-picker.h>
 #include <libgnomeui/gnome-entry.h>
-#include <libgnomeui/gnome-file-entry.h>
-#include <libgnomeui/gnome-font-picker.h>
-#include <libgnomeui/gnome-icon-entry.h>
-#include <libgnomeui/gnome-icon-item.h>
+#include <libgnomeui/gnome-image-entry.h>
+#include <libgnomeui/gnome-image-selector.h>
+
 #include <libgnomeui/gnome-icon-list.h>
-#include <libgnomeui/gnome-icon-sel.h>
+#include <libgnomeui/gnome-canvas-init.h>
 #include <libgnomeui/gnome-ui-init.h>
+#include <libgnomeui/gnome-macros.h>
 #include <libgnomeui/gnome-types.h>
 #include <libgnomeui/gnome-stock-icons.h>
-#include <libgnomeui/gnome-scores.h>
 #include <libgnomeui/gnome-client.h>
 #include <libgnomeui/gnome-dateedit.h>
 #include <libgnomeui/gnometypebuiltins.h>
+#include <libgnomeui/gnome-winhints.h>
 #include <libgnomeui/gnome-href.h>
-#include <libgnomeui/gnome-dialog.h>
-#include <libgnomeui/gnome-dialog-util.h>
 #include <libgnomeui/gnome-druid.h>
 #include <libgnomeui/gnome-druid-page.h>
 #include <libgnomeui/gnome-druid-page-edge.h>
 #include <libgnomeui/gnome-druid-page-standard.h>
-#include <libgnomeui/gnome-messagebox.h>
-#include <libgnomeui/gnome-mdi.h>
-#include <libgnomeui/gnome-mdi-child.h>
-#include <libgnomeui/gnome-mdi-generic-child.h>
-#include <libgnomeui/gnome-mdi-session.h>
 #include <libgnomeui/gnome-vfs-util.h>
-#include <libgnomeui/gnome-pixmap.h>
-#include <libgnomeui/gnome-pixmap-entry.h>
-#include <libgnomeui/gnome-popup-menu.h>
-#include <libgnomeui/gnome-propertybox.h>
-#include <libgnomeui/gnome-window-icon.h>
+
+#ifdef COMPAT_1_0
+#include "compat/1.0/libgnomeui-compat-1.0.h"
+#endif
 
 #endif
