@@ -28,17 +28,22 @@
 #define LIBGNOMEUIP_H
 
 #include <glib.h>
+#include <gobject/gsignal.h>
 #include <gtk/gtktypeutils.h>
 
 
-#include <libgnome/libgnome.h>
+#include <libgnome.h>
+#include "gnome-macros.h"
 #include "gnometypebuiltins.h"
-#include "gnome-gconf-ui.h"
 
 G_BEGIN_DECLS
 
 void gnome_type_init(void);
 
+/* FIXME: broken */
+extern const GList *gnome_i18n_get_language_list (const gchar *category_name);
+extern char *gnome_i18n_get_preferred_language (void);
+
 G_END_DECLS
 
 #endif /* LIBGNOMEUIP_H */
