@@ -35,6 +35,7 @@
 #include "testgnome.h"
 #include "bomb.xpm"
 
+#ifdef FIXME
 static const gchar *authors[] = {
 	"Richard Hestilow",
 	"Federico Mena",
@@ -46,6 +47,7 @@ static const gchar *authors[] = {
 	"Martin Baulig",
 	NULL
 };
+#endif
 
 static void
 test_exit (TestGnomeApp *app)
@@ -86,15 +88,16 @@ verb_FileExit_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname)
 static void
 verb_HelpAbout_cb (BonoboUIComponent *uic, gpointer user_data, const char *cname)
 {
-	const char *documentors[] = { "Documentor1", "Documentor2", NULL };
+#ifdef FIXME
 	GtkWidget *about = gnome_about_new ("GNOME Test Program", VERSION,
 					    "(C) 1998-2001 The Free Software Foundation",
 					    "Program to display GNOME functions.",
 					    authors,
-					    documentors,
+					    NULL,
 					    NULL,
 					    NULL);
 	gtk_widget_show (about);
+#endif
 }
 
 static BonoboUIVerb verbs[] = {
@@ -116,7 +119,7 @@ quit_test (GtkWidget *caller, GdkEvent *event, TestGnomeApp *app)
 static TestGnomeApp *
 create_newwin(gboolean normal, gchar *appname, gchar *title)
 {
-        TestGnomeApp *app;
+        TestGnomeApp		*app;
 
 	app = g_new0 (TestGnomeApp, 1);
 	app->app = bonobo_window_new (appname, title);
@@ -131,11 +134,7 @@ create_newwin(gboolean normal, gchar *appname, gchar *title)
 	bonobo_ui_component_set_container (app->ui_component,
 					   BONOBO_OBJREF(app->ui_container),
 					   NULL);
-
-	bonobo_ui_util_set_ui (app->ui_component, "",
-			       GNOMEUISRCDIR "/testgnome.xml",
-			       appname, NULL);
-
+	bonobo_ui_util_set_ui (app->ui_component, GNOMEUIDATADIR, "testgnome.xml", appname);
 	bonobo_ui_component_add_verb_list_with_data (app->ui_component, verbs, app);
 	
 	return app;
@@ -517,6 +516,7 @@ create_druid(void)
 	gnome_druid_set_page (GNOME_DRUID (druid), GNOME_DRUID_PAGE (page_start));
 	gtk_widget_show_all (window);
 }
+
 #endif
 
 /*
@@ -530,8 +530,9 @@ create_entry(void)
 	GtkWidget *entry;
 
 	app = create_newwin(TRUE,"testGNOME","Entry");
-	entry = gnome_entry_new(NULL);
+	entry = gnome_entry_new();
 	g_assert(entry != NULL);
+//	gnome_entry_set_text (GNOME_ENTRY(entry), "Foo");
 	bonobo_window_set_contents(BONOBO_WINDOW(app->app), entry);
 	gtk_widget_show(entry);
 	gtk_widget_show(app->app);
@@ -541,6 +542,8 @@ create_entry(void)
  * FileEntry
  */
 
+#if 0
+
 static void
 file_entry_update_files(GtkWidget *w, GnomeFileEntry *fentry)
 {
@@ -572,7 +575,7 @@ file_entry_modal_toggle(GtkWidget *w, GnomeFileEntry *fentry)
 static void
 file_entry_directory_toggle(GtkWidget *w, GnomeFileEntry *fentry)
 {
-	gnome_file_entry_set_directory_entry (fentry,GTK_TOGGLE_BUTTON(w)->active);
+	gnome_file_entry_set_directory(fentry,GTK_TOGGLE_BUTTON(w)->active);
 }
 
 static void
@@ -620,82 +623,35 @@ create_file_entry(void)
 	gtk_widget_show_all(app->app);
 }
 
-/*
- * IconEntry
- */
-static void
-create_icon_entry(void)
-{
-	TestGnomeApp *app;
-	GtkWidget *entry;
-
-	app = create_newwin (TRUE, "testGNOME", "Icon Entry");
-
-	entry = gnome_icon_entry_new ("Foo", "Icon");
-
-	bonobo_window_set_contents (BONOBO_WINDOW (app->app), entry);
-	gtk_widget_show (entry);
-	gtk_widget_show (app->app);
-}
-
-/*
- * PixmapEntry
- */
-static void
-create_pixmap_entry(void)
-{
-	TestGnomeApp *app;
-	GtkWidget *entry;
-
-	app = create_newwin (TRUE, "testGNOME", "Pixmap Entry");
-
-	entry = gnome_pixmap_entry_new ("Foo", "Pixmap", TRUE);
-
-	bonobo_window_set_contents (BONOBO_WINDOW (app->app), entry);
-	gtk_widget_show (entry);
-	gtk_widget_show (app->app);
-}
-
-#if 0
-/*
- * FontSelector
- */
-static void
-create_font_selector (void)
-{
-	g_warning ("Font '%s'", gnome_font_select ());
-}
 #endif
 
-
 /*
  * FontPicker
  */
+#if 0
 static void
 cfp_ck_UseFont(GtkWidget *widget,GnomeFontPicker *gfp)
 {
 	gboolean show;
+	gint size;
 
-	g_object_get (G_OBJECT (gfp),
-		      "use-font-in-label", &show,
-		      NULL);
-	show = ! show;
+	show=!gfp->use_font_in_label;
+	size=gfp->use_font_in_label_size;
+
+	gnome_font_picker_fi_set_use_font_in_label(gfp,show,size);
 
-	g_object_set (G_OBJECT (gfp),
-		      "use-font-in-label", show,
-		      NULL);
 }
 
 static void
 cfp_sp_value_changed(GtkAdjustment *adj,GnomeFontPicker *gfp)
 {
+	gboolean show;
 	gint size;
 
+	show=gfp->use_font_in_label;
 	size=(gint)adj->value;
 
-	g_object_set (G_OBJECT (gfp),
-		      "label-font-size", size,
-		      NULL);
+	gnome_font_picker_fi_set_use_font_in_label(gfp,show,size);
 
 }
 
@@ -737,7 +693,7 @@ create_font_picker (void)
 	bonobo_window_set_contents(BONOBO_WINDOW(app->app),vbox);
 
 	/* Pixmap */
-	frPixmap=gtk_frame_new("Default Pixmap");
+	frPixmap=gtk_frame_new(_("Default Pixmap"));
 	gtk_box_pack_start(GTK_BOX(vbox),frPixmap,TRUE,TRUE,0);
 	vbox1=gtk_vbox_new(FALSE,FALSE);
 	gtk_container_add(GTK_CONTAINER(frPixmap),vbox1);
@@ -746,7 +702,7 @@ create_font_picker (void)
 	fontpicker1 = gnome_font_picker_new();
 	gtk_container_set_border_width(GTK_CONTAINER(fontpicker1),5);
 	gtk_box_pack_start(GTK_BOX(vbox1),fontpicker1,TRUE,TRUE,0);
-	lbPixmap=gtk_label_new("If you choose a font it will appear here");
+	lbPixmap=gtk_label_new(_("If you choose a font it will appear here"));
 	gtk_box_pack_start(GTK_BOX(vbox1),lbPixmap,TRUE,TRUE,5);
 
 	gtk_signal_connect(GTK_OBJECT(fontpicker1),"font_set",
@@ -759,38 +715,34 @@ create_font_picker (void)
 	gtk_container_set_border_width(GTK_CONTAINER(vbox2),5);
 	gtk_container_add(GTK_CONTAINER(frFontInfo),vbox2);
 
-	fontpicker2 = gnome_font_picker_new();
-
 	/* GnomeFontPicker with fontinfo */
 	hbox1=gtk_hbox_new(FALSE,5);
 	gtk_box_pack_start(GTK_BOX(vbox2),hbox1,FALSE,FALSE,0);
-	ckUseFont=gtk_check_button_new_with_label("Use Font in button with size");
+	ckUseFont=gtk_check_button_new_with_label(_("Use Font in button with size"));
 	gtk_box_pack_start(GTK_BOX(hbox1),ckUseFont,TRUE,TRUE,0);
 
 	adj=GTK_ADJUSTMENT(gtk_adjustment_new(14,5,150,1,1,1));
-	gtk_signal_connect (GTK_OBJECT (adj), "value_changed",
-			    GTK_SIGNAL_FUNC (cfp_sp_value_changed),
-			    fontpicker2);
 	spUseFont=gtk_spin_button_new(adj,1,0);
 	gtk_box_pack_start(GTK_BOX(hbox1),spUseFont,FALSE,FALSE,0);
-	gtk_object_set_data (GTK_OBJECT (fontpicker2), "spUseFont", spUseFont);
 
-	gtk_signal_connect (GTK_OBJECT (ckUseFont), "toggled",
-			    GTK_SIGNAL_FUNC (cfp_ck_UseFont),
-			    fontpicker2);
-
-	ckShowSize=gtk_check_button_new_with_label("Show font size");
+	ckShowSize=gtk_check_button_new_with_label(_("Show font size"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(ckShowSize),TRUE);
 	gtk_box_pack_start(GTK_BOX(vbox2),ckShowSize,FALSE,FALSE,5);
 
-	gtk_signal_connect (GTK_OBJECT (ckShowSize), "toggled",
-			    GTK_SIGNAL_FUNC (cfp_ck_ShowSize),
-			    fontpicker2);
-
+	fontpicker2 = gnome_font_picker_new();
 	gnome_font_picker_set_mode(GNOME_FONT_PICKER(fontpicker2),GNOME_FONT_PICKER_MODE_FONT_INFO);
 	gtk_box_pack_start(GTK_BOX(vbox2),fontpicker2,TRUE,TRUE,0);
 
-	lbFontInfo=gtk_label_new("If you choose a font it will appear here");
+	gtk_signal_connect(GTK_OBJECT(ckUseFont),"toggled",
+			   (GtkSignalFunc)cfp_ck_UseFont,fontpicker2);
+
+	gtk_signal_connect(GTK_OBJECT(ckShowSize),"toggled",
+			   (GtkSignalFunc)cfp_ck_ShowSize,fontpicker2);
+
+	gtk_signal_connect(GTK_OBJECT(adj),"value_changed",
+			   (GtkSignalFunc)cfp_sp_value_changed,fontpicker2);
+
+	lbFontInfo=gtk_label_new(_("If you choose a font it will appear here"));
 	gtk_box_pack_start(GTK_BOX(vbox2),lbFontInfo,TRUE,TRUE,5);
 
 
@@ -809,16 +761,15 @@ create_font_picker (void)
 	gnome_font_picker_set_mode(GNOME_FONT_PICKER(fontpicker3),GNOME_FONT_PICKER_MODE_USER_WIDGET);
 
 	hbox3=gtk_hbox_new(FALSE,0);
-	gtk_box_pack_start(GTK_BOX(hbox3),gtk_image_new_from_stock
-                           (GNOME_STOCK_PIXMAP_SPELLCHECK, GTK_ICON_SIZE_BUTTON),
+	gtk_box_pack_start(GTK_BOX(hbox3),gnome_stock_new_with_icon(GNOME_STOCK_PIXMAP_SPELLCHECK),
 			   FALSE,FALSE,5);
-	gtk_box_pack_start(GTK_BOX(hbox3),gtk_label_new("This is an hbox with pixmap and text"),
+	gtk_box_pack_start(GTK_BOX(hbox3),gtk_label_new(_("This is an hbox with pixmap and text")),
 			   FALSE,FALSE,5);
 	gnome_font_picker_uw_set_widget(GNOME_FONT_PICKER(fontpicker3),hbox3);
 	gtk_container_set_border_width(GTK_CONTAINER(fontpicker3),5);
 	gtk_box_pack_start(GTK_BOX(vbox3),fontpicker3,TRUE,TRUE,0);
 
-	lbUser=gtk_label_new("If you choose a font it will appear here");
+	lbUser=gtk_label_new(_("If you choose a font it will appear here"));
 	gtk_box_pack_start(GTK_BOX(vbox3),lbUser,TRUE,TRUE,5);
 
 	gtk_signal_connect(GTK_OBJECT(fontpicker3),"font_set",
@@ -827,8 +778,7 @@ create_font_picker (void)
 	gtk_widget_show_all(app->app);
 
 }
-
-
+#endif
 /*
  * HRef
  */
@@ -967,7 +917,6 @@ create_icon_list(void)
 /*
  * ImageEntry
  */
-#if 0
 
 static void
 create_image_entry(void)
@@ -976,13 +925,12 @@ create_image_entry(void)
 	GtkWidget *entry;
 
 	app = create_newwin(TRUE,"testGNOME","Pixmap Entry");
-	entry = gnome_pixmap_entry_new (NULL, "Test", FALSE);
+	/* FIXME: The gnome_image_entry_new param. must be reviewed */
+	entry = gnome_image_entry_new_pixmap_entry (0,0);
 	bonobo_window_set_contents(BONOBO_WINDOW(app->app),entry);
 	gtk_widget_show(entry);
 	gtk_widget_show(app->app);
 }
-#endif
-
 #if 0
 /*
  * ImageSelector
@@ -1023,22 +971,6 @@ create_unit_spinner (void)
 
 }
 #endif
-
-static void
-create_about_box (void)
-{
-	const char *documentors[] = { "Documentor1", "Documentor2", NULL };
-	GtkWidget *about_box = gnome_about_new ("Test GNOME",
-						VERSION,
-						"(c) 2001 Foo, Inc.\n(c) 2001 Bar, Inc.",
-						"This is the testing gnome application about box",
-						authors,
-						documentors,
-						"Translation credits",
-						NULL /* logo pixbuf */);
-	gtk_widget_show (about_box);
-}
-
 int
 main (int argc, char **argv)
 {
@@ -1050,20 +982,16 @@ main (int argc, char **argv)
 		{ "color picker", create_color_picker },
 		{ "date edit", create_date_edit },
 /*		{ "ditem edit", create_ditem_edit },*/
-/*		{ "druid", create_druid }, */
+/*		{ "druid", create_druid },*/
 		{ "entry", create_entry },
-		{ "file entry", create_file_entry },
-		{ "pixmap entry", create_pixmap_entry },
-		{ "icon entry", create_icon_entry },
-/*		{ "font selector", create_font_selector }, */
-		{ "font picker", create_font_picker },
+/*		{ "file entry", create_file_entry },*/
+/*		{ "font picker", create_font_picker },*/
 		{ "href", create_href },
 		{ "icon list", create_icon_list },
-/*		{ "image entry", create_image_entry }, */
+		{ "image entry", create_image_entry },
 /*		{ "image selector", create_image_selector },*/
 /*		{ "paper selector", create_papersel },*/
 /*		{ "unit spinner", create_unit_spinner },*/
-		{ "about box", create_about_box }
 	  };
 	int nbuttons = sizeof (buttons) / sizeof (buttons[0]);
 	TestGnomeApp *app;
@@ -1074,8 +1002,7 @@ main (int argc, char **argv)
 	int i;
 
 	
-	gnome_program_init ("testGNOME", VERSION,
-			    LIBGNOMEUI_MODULE,
+	gnome_program_init ("testGNOME", VERSION, &libgnomeui_module_info,
 			    argc, argv, NULL);
 
 	app = create_newwin (FALSE, "testGNOME", "testGNOME");
@@ -1112,7 +1039,8 @@ main (int argc, char **argv)
 
 	gtk_widget_show (app->app);
 
-	gtk_main ();
+	bonobo_main ();
 
 	return 0;
 }
+
